@@ -1,5 +1,5 @@
 /* cfed -- a level editor for Crimson Fields
-   Copyright (C) 2000-2003 Jens Granseuer
+   Copyright (C) 2000-2004 Jens Granseuer
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -329,16 +329,14 @@ int parse( FILE *in ) {
                 err = 1;
                 fprintf( stderr, "Error in line %ld: Illegal owner of building\n", line );
               }
-            } else if ( strncasecmp( buf, "mining", 6 ) == 0 ) {					/* mining */
-              cbuild->b_crystalprod = atoi( p ); 
-              cbuild->b_flags |= BLD_MINE;
-            } else if ( strncasecmp( buf, "crystals", 8 ) == 0 ) cbuild->b_crystals = atoi( p );	/* resources */
+            } else if ( strncasecmp( buf, "mining", 6 ) == 0 ) cbuild->b_crystalprod = atoi( p );	/* mining */
+            else if ( strncasecmp( buf, "crystals", 8 ) == 0 ) cbuild->b_crystals = atoi( p );	/* resources */
             else if ( strncasecmp( buf, "capacity", 8 ) == 0 ) cbuild->b_maxcrystals = atoi( p );	/* max. resources */
             else if ( strncasecmp( buf, "minweight", 9 ) == 0 ) cbuild->b_minweight = atoi( p );	/* smallest unit allowed */
             else if ( strncasecmp( buf, "maxweight", 9 ) == 0 ) cbuild->b_maxweight = atoi( p );	/* biggest unit allowed */
             else if ( strncasecmp( buf, "type", 4 ) == 0 ) {						/* type */
               if ( strncasecmp( p, "workshop", 8 ) == 0 ) cbuild->b_flags |= BLD_WORKSHOP;
-              else if ( strncasecmp( p, "mine", 4 ) == 0 ) cbuild->b_flags |= BLD_MINE;
+              else if ( strncasecmp( p, "mine", 4 ) == 0 ) fprintf( stderr, "Warning: Deprecated shop type 'mine' found. Ignored.\n" );
               else if ( strncasecmp( p, "factory", 7 ) == 0 ) cbuild->b_flags |= BLD_FACTORY;
               else {
                 err = 1;
@@ -569,8 +567,8 @@ int parse( FILE *in ) {
 
       for ( i = 0; i < 2; ++i ) {	/* save player information */
         SDL_RWwrite( out, &players[i].p_id, 1, 4 );
-        SDL_RWwrite( out, &players[i].p_name, 1, 16 );
-        SDL_RWwrite( out, &players[i].p_password, 1, 8 );
+        SDL_RWwrite( out, players[i].p_name, 1, 16 );
+        SDL_RWwrite( out, players[i].p_password, 1, 8 );
       }
 
       SDL_WriteLE16( out, game.num_buildings );
@@ -1115,7 +1113,7 @@ int check_buildings( struct List *l, struct List *units, unsigned short *map, st
     }
 
     if ( b->b_name[0] == '\0' ) {
-      if ( b->b_flags & BLD_MINE ) strcpy( b->b_name, "Mining Station" );
+      if ( b->b_crystalprod > 0 ) strcpy( b->b_name, "Mining Station" );
       else if ( b->b_flags & BLD_FACTORY ) strcpy( b->b_name, "Factory" );
       else strcpy( b->b_name, "Depot" );
     }
@@ -1364,7 +1362,7 @@ int check_events( struct List *events, struct List *units, struct List *builds,
         while ( walk->ln_Next ) {
           u = walk->ln_Data;
           if ( u->u_id == e->e_tdata[0] ) {
-            if ( (u->u_pid == e->e_tdata[1]) && (e->e_tdata[2] < 0)  ) {
+            if ( (u->u_pid == e->e_tdata[1]) && (e->e_tdata[2] < 0) && (e->e_depend == -1) ) {
               fprintf( stderr, "Error: Event trigger: unit %d is already owned by player %d (%d)\n", u->u_id, u->u_pid+1, e->e_id );
               return 1;
             }
@@ -1391,7 +1389,7 @@ int check_events( struct List *events, struct List *units, struct List *builds,
         while ( walk->ln_Next ) {
           b = walk->ln_Data;
           if ( b->b_id == e->e_tdata[0] ) {
-            if ( (b->b_player == e->e_tdata[1]) && (e->e_tdata[2] < 0) ) {
+            if ( (b->b_player == e->e_tdata[1]) && (e->e_tdata[2] < 0) && (e->e_depend == -1)) {
               fprintf( stderr, "Error: Event trigger: building %d is already owned by player %d (%d)\n", b->b_id, b->b_player+1, e->e_id );
               return 1;
             }
