@@ -1,5 +1,5 @@
 // Crimson Fields -- a game of tactical warfare
-// Copyright (C) 2000-2003 Jens Granseuer
+// Copyright (C) 2000-2004 Jens Granseuer
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -109,7 +109,7 @@ Game::~Game( void ) {
 void Game::Quit( void ) const {
   Audio::PlaySfx( Audio::SND_GUI_ASK, 0 );
   DialogWindow *req = new DialogWindow( NULL, "Do you really want to quit?",
-                      "yYes|nNo", 1, 0, view );
+                      "_Yes|_No", 1, 0, view );
   req->SetButtonID( 0, GUI_QUIT );
 }
 
@@ -137,7 +137,7 @@ string Game::CreateSaveFileName( const char *filename ) const {
       char *conmsg = new char[ file.length() + 20 ];
       strcpy( conmsg, file.c_str() );
       strcat( conmsg, " exists. Overwrite?" );
-      dw = new DialogWindow( NULL, conmsg, "yYes|nNo", 1, 0, view );
+      dw = new DialogWindow( NULL, conmsg, "_Yes|_No", 1, 0, view );
       dw->SetButtonID( 0, 1 );
       dw->SetButtonID( 1, 0 );
       rc = dw->EventLoop();
@@ -166,7 +166,7 @@ string Game::CreateSaveFileName( const char *filename ) const {
           if ( flags & GI_PBEM ) {
             // if saving a PBeM game is aborted the game data is lost...
             dw = new DialogWindow( "Warning", "Really abort? Current game will be lost!",
-                                   "wSo what?|oOops!", 1, WIN_FONT_BIG, view );
+                                   "So _what?|_Oops!", 1, WIN_FONT_BIG, view );
             Audio::PlaySfx( Audio::SND_GUI_ASK, 0 );
             dw->SetButtonID( 0, 1 );
             dw->SetButtonID( 1, 0 );
@@ -554,7 +554,7 @@ void Game::StartTurn( void ) {
   // in email games set up or check player passwords
   if ( flags & GI_PBEM ) {
     if ( !player->Password() ) SetPlayerPassword( player );
-    else CheckPassword( player->Name(), "Enter password",
+    else CheckPassword( player->Name(), "Enter _password",
                         player->Password(), true );
   }
 
@@ -614,7 +614,7 @@ void Game::StartTurn( void ) {
 void Game::SetPlayerPassword( Player *player ) const {
   bool pw_ok = false;
   PasswordWindow *pwin;
-  const char *pw, *msg1 = "Choose a password";
+  const char *pw, *msg1 = "Choose a _password";
 
   pwin = new PasswordWindow( player->Name(), msg1,
                              player->Password(), view );
@@ -1271,7 +1271,7 @@ GUI_Status Game::HandleEvent( const SDL_Event &event ) {
       MoveCommand( event.key.keysym.sym );
       break;
     case SDLK_SPACE:      // select the unit underneath the cursor
-      SelectCommand();
+      SelectCommand( mv->Cursor() );
       break;
     case SDLK_c: {        // show transport or building contents
       MapObject *mo = map->GetMapObject( mv->Cursor() );
@@ -1320,8 +1320,7 @@ GUI_Status Game::HandleEvent( const SDL_Event &event ) {
     Point pos;
     if ( event.button.button == SDL_BUTTON_LEFT ) {
       if ( !mv->Pixel2Hex( event.button.x - mwin->x, event.button.y - mwin->y, pos ) ) {
-        if ( pos == mv->Cursor() ) SelectCommand();
-        else SetCursor( pos );
+        HandleLMB( pos );
       }
     } else if ( !mv->Pixel2Hex( event.button.x - mwin->x, event.button.y - mwin->y, pos ) ) {
       Unit *u = map->GetUnit( pos );
@@ -1376,43 +1375,67 @@ void Game::MoveCommand( int key ) {
 // DESCRIPTION: Got a select command from the user. See what he wants to
 //              do. Select/deselect a unit, enter a building, or attack
 //              an enemy unit.
-// PARAMETERS : -
+// PARAMETERS : hex - selected hex
 // RETURNS    : -
 ////////////////////////////////////////////////////////////////////////
 
-void Game::SelectCommand( void ) {
+void Game::SelectCommand( const Point &hex ) {
   MapView *mv = mwin->GetMapView();
   Point cursor = mv->Cursor();
 
-  Unit *u = map->GetUnit( cursor );
+  Unit *u = map->GetUnit( hex );
 
   if ( player->Mode() == MODE_BUSY ) {
     if ( u ) {
       if ( u->Owner() == player ) {
-        if ( cursor == unit->Position() ) DeselectUnit();
-        else if ( shader->GetStep(cursor) != -1 )
-          MoveUnit( unit, cursor );    // try to move into transport
+        if ( u == unit ) DeselectUnit();
+        else if ( shader->GetStep(hex) != -1 )
+          MoveUnit( unit, hex );    // try to move into transport
         else SelectUnit( u );
       } else if ( unit->CanHit( u ) ) {   // attack the unit
         RegisterCombat( unit, u );
         DeselectUnit();
       }
-    } else if ( unit->Position() == cursor ) DeselectUnit();
-    else MoveUnit( unit, cursor );  // try to move there
+    } else if ( unit->Position() == hex ) DeselectUnit();
+    else MoveUnit( unit, hex );  // try to move there
   } else if ( player->Mode() == MODE_IDLE ) {
     if ( u && (u->Owner() == player) ) SelectUnit( u );
     else {
-      Building *b = map->GetBuilding( cursor );
+      Building *b = map->GetBuilding( hex );
       if ( b ) ContainerContent( b );
     }
   } else if ( player->Mode() == MODE_SWEEP ) {
-    if ( (shader->GetStep( cursor ) != -1) &&
+    if ( (shader->GetStep( hex ) != -1) &&
          (cursor != unit->Position()) )
       ClearMine( static_cast<Transport *>(unit), u );
     else DeselectUnit();
   }
 }
 
+////////////////////////////////////////////////////////////////////////
+// NAME       : Game::HandleLMB
+// DESCRIPTION: React to user pressing the left mouse button.
+// PARAMETERS : hex - hex the user clicked on
+// RETURNS    : -
+////////////////////////////////////////////////////////////////////////
+
+void Game::HandleLMB( const Point &hex ) {
+
+  bool move = (hex != mwin->GetMapView()->Cursor());
+  Unit *u = map->GetUnit( hex );
+
+  // activate selection if the user
+  // - clicked the same hex twice or
+  // - clicked a unit which is neither hostile, a mine, or a valid
+  //   transporter for the currently selected unit
+  if ( !move || (u && !(unit && ((unit == u) ||
+        (u->Owner() != player) || u->IsMine() ||
+        (u->IsTransport() && (shader->GetStep(hex) != -1))))) )
+    SelectCommand( hex );
+
+  else if ( move ) SetCursor( hex );
+}
+
 ////////////////////////////////////////////////////////////////////////
 // NAME       : Game::ContainerContent
 // DESCRIPTION: Open a window to display the content of a transport or
@@ -1550,23 +1573,23 @@ void Game::ShowDebriefing( Player *player, bool restart ) {
 void Game::GameMenu( void ) {
   MenuWindow *menu = new MenuWindow( PROGRAMNAME, this, view );
 
-  menu->AddItem( 0, G_BUTTON_END_TURN, 0, "End Turn", 'e' );
-  menu->AddItem( 0, G_BUTTON_MAP,      0, "Map", 'm' );
-  menu->AddItem( 0, G_BUTTON_BRIEFING, 0, "Briefing", 'b' );
+  menu->AddItem( 0, G_BUTTON_END_TURN, 0, "_End Turn" );
+  menu->AddItem( 0, G_BUTTON_MAP,      0, "_Map" );
+  menu->AddItem( 0, G_BUTTON_BRIEFING, 0, "_Briefing" );
   menu->AddBar( 0 );
-  menu->AddItem( 0, G_BUTTON_LEV_INFO, 0, "Level Info", 'l' );
-  menu->AddMenu( 0, 0, "Options", 'o' );
-  menu->AddItem( 1, G_BUTTON_GENERAL_OPTIONS, 0, "General", 'g' );
-  menu->AddItem( 1, G_BUTTON_VIDEO_OPTIONS, 0, "Video", 'v' );
+  menu->AddItem( 0, G_BUTTON_LEV_INFO, 0, "_Level Info" );
+  menu->AddMenu( 0, 0, "_Options" );
+  menu->AddItem( 1, G_BUTTON_GENERAL_OPTIONS, 0, "_General" );
+  menu->AddItem( 1, G_BUTTON_VIDEO_OPTIONS, 0, "_Video" );
 #ifndef DISABLE_SOUND
-  menu->AddItem( 1, G_BUTTON_SOUND_OPTIONS, 0, "Sound", 's' );
+  menu->AddItem( 1, G_BUTTON_SOUND_OPTIONS, 0, "_Sound" );
 #endif
   menu->AddBar( 0 );
   menu->AddItem( 0, G_BUTTON_SAVE, 
                  (flags & GI_PBEM) ? WIDGET_DISABLED : 0,
-                 "Save...", 's' );
-  menu->AddItem( 0, G_BUTTON_ABORT,    0, "Abort...", 'a' );
-  menu->AddItem( 0, G_BUTTON_QUIT,     0, "Quit...", 'q' );
+                 "_Save..." );
+  menu->AddItem( 0, G_BUTTON_ABORT,    0, "_Abort..." );
+  menu->AddItem( 0, G_BUTTON_QUIT,     0, "_Quit..." );
 
   menu->Layout();
 }
@@ -1586,14 +1609,14 @@ void Game::UnitMenu( Unit *u ) {
   if ( transport || sweeper ) {
     MenuWindow *menu = new MenuWindow( u->Name(), this, view );
 
-    menu->AddItem( 0, G_BUTTON_UNIT_INFO, 0, "Info", 'i' );
+    menu->AddItem( 0, G_BUTTON_UNIT_INFO, 0, "_Info" );
 
     if ( transport )
-      menu->AddItem( 0, G_BUTTON_UNIT_CONTENT, 0, "Content", 'c' );
+      menu->AddItem( 0, G_BUTTON_UNIT_CONTENT, 0, "_Content" );
 
     if ( sweeper )
       menu->AddItem( 0, G_BUTTON_UNIT_SWEEP,
-                     (u->IsReady() ? 0 : WIDGET_DISABLED), "Sweep", 's' );
+                     (u->IsReady() ? 0 : WIDGET_DISABLED), "_Sweep Mine" );
 
     menu->Layout();
     g_tmp_prv_unit = u;
@@ -1669,7 +1692,7 @@ GUI_Status Game::WidgetActivated( Widget *button, Window *win ) {
     view->CloseWindow( win );
     Audio::PlaySfx( Audio::SND_GUI_ASK, 0 );
     DialogWindow *req = new DialogWindow( NULL, "Return to main menu?",
-                        "yYes|nNo", 1, 0, view );
+                        "_Yes|_No", 1, 0, view );
     req->SetButtonID( 0, GUI_RESTART );
     break; }
   case G_BUTTON_QUIT:
