@@ -35,7 +35,6 @@ extern Options CFOptions;
 ////////////////////////////////////////////////////////////////////////
 
 HistEvent::HistEvent( void ) {
-  type = HIST_DONE;
 }
 
 ////////////////////////////////////////////////////////////////////////
@@ -152,11 +151,11 @@ void History::Replay( MapWindow *mapwin ) {
   MapView *mv = mapwin->GetMapView();
   Map *map = mv->GetMap();
   ProgressWindow *progwin = NULL;
-  MessageWindow *msgw;
   HistEvent *he = static_cast<HistEvent *>( events.Head() );
 
   bool abort = false;
   bool replay = CFOptions.GetTurnReplay();
+  bool quick = CFOptions.GetQuickReplay();
 
   if ( replay ) {
     List units_bak;
@@ -167,117 +166,38 @@ void History::Replay( MapWindow *mapwin ) {
     // undo the map tile changes which have been recorded this turn
     while ( he && (he->type == HIST_TILE_INTERNAL) ) {
       map->SetHexType( he->data[1], he->data[2], he->data[0] );
-      he->type = HIST_DONE;
       he = static_cast<HistEvent *>( he->Next() );
       --count;
     }
 
-    mv->Enable();
-    mapwin->Draw();
-    mapwin->Show();
+    if ( quick ) delay = 0;
+    else {
+      delay = DEFAULT_DELAY;
+      mv->Enable();
+      mapwin->Draw();
+      mapwin->Show();
+    }
+
     progwin = new ProgressWindow( 5,
               mapwin->Height() - view->SmallFont()->Height() - 30,
               mapwin->Width() / 2, view->SmallFont()->Height() + 20,
               0, count, WIN_PROG_ABORT, view );
 
-    Unit *lastunit = NULL;
-    Point lastpos( -1, -1 );
-    Rect upd;
-
     while ( he && !abort ) {
-      Unit *u;
 
       switch ( he->type ) {
-        case HIST_MOVE:              // move unit
-          u = Gam->GetUnitByID( he->data[0] );
-          if ( u ) {
-            if ( u != lastunit ) {
-              if ( lastunit && lastunit->IsTransport() && !map->GetMapObject( lastpos ) ) {
-                // we must adjust the position of carried units manually because
-                // those pseudo-transports can't handle this themselves
-                for ( Unit *carry = static_cast<Unit *>( Gam->UnitsList()->Head() );
-                      carry; carry = static_cast<Unit *>( carry->Next() ) ) {
-                  if ( carry->Position() == lastpos )
-                    carry->SetPosition( lastunit->Position().x, lastunit->Position().y );
-                }
-              }
-              lastunit = u;
-              lastpos = u->Position();
-
-              SDL_Delay( DEFAULT_DELAY );
-            }
-
-            if ( !mv->HexVisible( u->Position() ) ) {
-              mv->CenterOnHex( u->Position() );
-              mapwin->Show( *mv );
-            }
-
-            if ( u->IsSheltered() ) {
-              if ( map->GetUnit( u->Position() ) ) u->UnsetFlags( U_SHELTERED );
-              else map->GetBuilding( u->Position() )->RemoveUnit( u );
-            } else {
-              map->SetUnit( NULL, u->Position() );
-              mv->UpdateHex( u->Position() );
-            }
-
-            Gam->MoveUnit( u, (Direction)he->data[1] );
-            map->SetUnit( u, u->Position() );
-            mapwin->Show( mv->UpdateHex( u->Position() ) );
-          }
-          break;
+        case HIST_MOVE:
+          ReplayMoveEvent( *he, mapwin ); break;
         case HIST_ATTACK:
-          u = Gam->GetUnitByID( he->data[0] );
-          if ( u ) {
-            if ( u != lastunit ) SDL_Delay( DEFAULT_DELAY );
-            if ( !mv->HexVisible( u->Position() ) ||
-                 !mv->HexVisible( Point(he->data[1], he->data[2]) ) ) {
-              mv->CenterOnHex( Point((u->Position().x + he->data[1]) / 2,
-                                (u->Position().y + he->data[2]) / 2) );
-              mapwin->Show( *mv );
-            }
-            mv->SetCursorImage( IMG_CURSOR_HIGHLIGHT );
-            upd = mv->SetCursor( u->Position() );
-            mapwin->Show( upd );
-            mv->SetCursorImage( IMG_CURSOR_ATTACK );
-            upd = mv->SetCursor( Point(he->data[1], he->data[2]) );
-            mapwin->Show( upd );
-            mv->SetCursor( Point(-1,-1) );
-            SDL_Delay( DEFAULT_DELAY );
-            upd = mv->UpdateHex( u->Position() );
-            mapwin->Show( upd );
-            upd = mv->UpdateHex( Point(he->data[1], he->data[2]) );
-            mapwin->Show( upd );
-            lastunit = u;
-          }
-          break;
-        case HIST_COMBAT: {
-          Combat cmb( Gam->GetUnitByID( he->data[0] ),
-                      Gam->GetUnitByID( he->data[1] ) );
-          cmb.aamod = (signed char)he->data[3];
-          cmb.ddmod = (signed char)he->data[2];
-          CombatWindow *cwin = cmb.Resolve( mapwin, view );
-          if ( cwin ) {
-            cwin->EventLoop();
-            view->CloseWindow( cwin );
-          }
-          break; }
+          ReplayAttackEvent( *he, mapwin ); break;
+        case HIST_COMBAT:
+          ReplayCombatEvent( *he, mapwin ); break;
         case HIST_TILE:
-          map->SetHexType( he->data[1], he->data[2], he->data[0] );
-          upd = mv->UpdateHex( Point(he->data[1], he->data[2]) );
-          mapwin->Show( upd );
-          SDL_Delay( DEFAULT_DELAY );
-          break;
+          ReplayTileEvent( *he, mapwin ); break;
         case HIST_MSG:
-          msgw = new MessageWindow(
-            (he->data[0] != -1) ? Gam->GetMessage( he->data[0] ) : "Message",
-            Gam->GetMessage( he->data[1] ), view );
-          msgw->EventLoop();
-          view->CloseWindow( msgw );
-          break;
-        default:
-          break;
+          ReplayMessageEvent( *he, view ); break;
+        default: break;
       }
-      he->type = HIST_DONE;
       he = static_cast<HistEvent *>( he->Next() );
       progwin->Advance( 1 );
       abort = progwin->Aborted();
@@ -286,19 +206,13 @@ void History::Replay( MapWindow *mapwin ) {
     EndReplay( units_bak, map );
   }
 
-  if ( replay && !abort ) SDL_Delay( DEFAULT_DELAY * 2 );
+  if ( replay && !abort ) SDL_Delay( delay * 2 );
   else {
     // if replay has been stopped or disabled we still need to revert
     // all changes to the map and display the cached messages
     while ( he ) {
       if ( he->type == HIST_TILE ) map->SetHexType( he->data[1], he->data[2], he->data[0] );
-      else if ( he->type == HIST_MSG ) {
-        msgw = new MessageWindow(
-          (he->data[0] != -1) ? Gam->GetMessage( he->data[0] ) : "Message",
-          Gam->GetMessage( he->data[1] ), view );
-        msgw->EventLoop();
-        view->CloseWindow( msgw );
-      }
+      else if ( he->type == HIST_MSG ) ReplayMessageEvent( *he, view );
       he = static_cast<HistEvent *>( he->Next() );
     }
   }
@@ -334,6 +248,9 @@ void History::BeginReplay( List &backup, Map *map ) {
       if ( u->IsMine() ) u->SetMoves( MCOST_MIN );
     }
   }
+
+  lastunit = NULL;
+  lastpos = Point(-1, -1);
 }
 
 ////////////////////////////////////////////////////////////////////////
@@ -481,3 +398,151 @@ int History::RecordMsgEvent( short title, unsigned short msg ) {
   return 0;
 }
 
+////////////////////////////////////////////////////////////////////////
+// NAME       : History::ReplayMoveEvent
+// DESCRIPTION: Show the movement of a unit from one hex to another,
+//              neighboring hex.
+// PARAMETERS : event  - move event
+//              mapwin - map window
+// RETURNS    : -
+////////////////////////////////////////////////////////////////////////
+
+void History::ReplayMoveEvent( const HistEvent &event, MapWindow *mapwin ) {
+  MapView *mv = mapwin->GetMapView();
+  Map *map = mv->GetMap();
+  Unit *u = Gam->GetUnitByID( event.data[0] );
+  if ( u ) {
+    if ( u != lastunit ) {
+      if ( lastunit && lastunit->IsTransport() && !map->GetMapObject( lastpos ) ) {
+        // we must adjust the position of carried units manually because
+        // those pseudo-transports can't handle this themselves
+        for ( Unit *carry = static_cast<Unit *>( Gam->UnitsList()->Head() );
+              carry; carry = static_cast<Unit *>( carry->Next() ) ) {
+          if ( carry->Position() == lastpos )
+             carry->SetPosition( lastunit->Position().x, lastunit->Position().y );
+        }
+      }
+      lastunit = u;
+      lastpos = u->Position();
+
+      SDL_Delay( delay );
+    }
+
+    if ( !mv->HexVisible( u->Position() ) ) {
+      mv->CenterOnHex( u->Position() );
+      mapwin->Show( *mv );
+    }
+
+    if ( u->IsSheltered() ) {
+      if ( map->GetUnit( u->Position() ) ) u->UnsetFlags( U_SHELTERED );
+      else map->GetBuilding( u->Position() )->RemoveUnit( u );
+    } else {
+      map->SetUnit( NULL, u->Position() );
+      mv->UpdateHex( u->Position() );
+    }
+
+    Gam->MoveUnit( u, (Direction)event.data[1] );
+    map->SetUnit( u, u->Position() );
+    mapwin->Show( mv->UpdateHex( u->Position() ) );
+  }
+}
+
+////////////////////////////////////////////////////////////////////////
+// NAME       : History::ReplayAttackEvent
+// DESCRIPTION: Show a unit targetting another one.
+// PARAMETERS : event  - attack event
+//              mapwin - map window
+// RETURNS    : -
+////////////////////////////////////////////////////////////////////////
+
+void History::ReplayAttackEvent( const HistEvent &event, MapWindow *mapwin ) {
+  MapView *mv = mapwin->GetMapView();
+  Unit *u = Gam->GetUnitByID( event.data[0] );
+  if ( u ) {
+
+    if ( u != lastunit ) SDL_Delay( delay );
+    if ( !mv->HexVisible( u->Position() ) ||
+         !mv->HexVisible( Point(event.data[1], event.data[2]) ) ) {
+      mv->CenterOnHex( Point((u->Position().x + event.data[1]) / 2,
+                             (u->Position().y + event.data[2]) / 2) );
+      mapwin->Show( *mv );
+    }
+    mv->SetCursorImage( IMG_CURSOR_HIGHLIGHT );
+    Rect upd = mv->SetCursor( u->Position() );
+    mapwin->Show( upd );
+    mv->SetCursorImage( IMG_CURSOR_ATTACK );
+    upd = mv->SetCursor( Point(event.data[1], event.data[2]) );
+    mapwin->Show( upd );
+    mv->SetCursor( Point(-1,-1) );
+    SDL_Delay( delay );
+    upd = mv->UpdateHex( u->Position() );
+    mapwin->Show( upd );
+    upd = mv->UpdateHex( Point(event.data[1], event.data[2]) );
+    mapwin->Show( upd );
+    lastunit = u;
+  }
+}
+
+////////////////////////////////////////////////////////////////////////
+// NAME       : History::ReplayMessageEvent
+// DESCRIPTION: Display a message.
+// PARAMETERS : event - message event
+//              view  - current view
+// RETURNS    : -
+////////////////////////////////////////////////////////////////////////
+
+void History::ReplayMessageEvent( const HistEvent &event, View *view ) {
+  MessageWindow *msgw = new MessageWindow(
+    (event.data[0] != -1) ? Gam->GetMessage( event.data[0] ) : "Message",
+    Gam->GetMessage( event.data[1] ), view );
+  msgw->EventLoop();
+  view->CloseWindow( msgw );
+}
+
+////////////////////////////////////////////////////////////////////////
+// NAME       : History::ReplayTileEvent
+// DESCRIPTION: Replay a tile switch.
+// PARAMETERS : event  - tile event
+//              mapwin - map window
+// RETURNS    : -
+////////////////////////////////////////////////////////////////////////
+
+void History::ReplayTileEvent( const HistEvent &event, MapWindow *mapwin ) {
+  MapView *mv = mapwin->GetMapView();
+  Map *map = mv->GetMap();
+
+  map->SetHexType( event.data[1], event.data[2], event.data[0] );
+  mapwin->Show( mv->UpdateHex( Point(event.data[1], event.data[2]) ) );
+  SDL_Delay( delay );
+}
+
+////////////////////////////////////////////////////////////////////////
+// NAME       : History::ReplayCombatEvent
+// DESCRIPTION: Replay a fight switch.
+// PARAMETERS : event  - combat event
+//              mapwin - map window
+// RETURNS    : -
+////////////////////////////////////////////////////////////////////////
+
+void History::ReplayCombatEvent( const HistEvent &event, MapWindow *mapwin ) {
+
+  // for the quick replay we may have to activate the display now
+  MapView *mv = mapwin->GetMapView();
+  if (!mv->Enabled()) {
+    delay = DEFAULT_DELAY;
+    mv->Enable();
+    mapwin->Draw();
+    mapwin->Show();
+  }
+
+  Combat cmb( Gam->GetUnitByID( event.data[0] ),
+              Gam->GetUnitByID( event.data[1] ) );
+  cmb.aamod = (signed char)event.data[3];
+  cmb.ddmod = (signed char)event.data[2];
+  CombatWindow *cwin = cmb.Resolve( mapwin, mapwin->GetView() );
+  if ( cwin ) {
+    cwin->EventLoop();
+    mapwin->GetView()->CloseWindow( cwin );
+  }
+}
+
