@@ -31,8 +31,7 @@ enum {  HIST_MOVE = 0,
         HIST_COMBAT,
         HIST_TILE,      // map tile change
         HIST_TILE_INTERNAL,
-        HIST_MSG,
-        HIST_DONE
+        HIST_MSG
 };
 
 class HistEvent : public Node {
@@ -61,12 +60,24 @@ public:
   int RecordMsgEvent( short title, unsigned short msg );
 
   void Replay( MapWindow *mapwin );
+
+private:
   void BeginReplay( List &backup, Map *map );
   void EndReplay( List &backup, Map *map );
 
-private:
+  void ReplayMoveEvent( const HistEvent &event, MapWindow *mapwin );
+  void ReplayAttackEvent( const HistEvent &event, MapWindow *mapwin );
+  void ReplayTileEvent( const HistEvent &event, MapWindow *mapwin );
+  void ReplayCombatEvent( const HistEvent &event, MapWindow *mapwin );
+  void ReplayMessageEvent( const HistEvent &event, View *view );
+
   List events;
   List units;
+
+  unsigned short delay;
+
+  Unit *lastunit;
+  Point lastpos;
 };
 
 #endif	/* _INCLUDE_HISTORY_H */
