@@ -1,5 +1,5 @@
 // Crimson Fields -- a game of tactical warfare
-// Copyright (C) 2000-2003 Jens Granseuer
+// Copyright (C) 2000-2004 Jens Granseuer
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -52,10 +52,6 @@ struct initLevInfo {    // used as user_data for the LevListWidget
 };
 
 const short GenericOptionsWindow::B_ID_OK      = 1;
-const short SoundOptionsWindow::B_ID_SFX       = 10;
-const short SoundOptionsWindow::B_ID_MUSIC     = 11;
-const short SoundOptionsWindow::S_ID_VOL_SFX   = 12;
-const short SoundOptionsWindow::S_ID_VOL_MUSIC = 13;
 
 ////////////////////////////////////////////////////////////////////////
 // NAME       : LevListWidget::PrintItem
@@ -127,42 +123,43 @@ InitWindow::InitWindow( View *view, Window *title ) : Window( WIN_CENTER, view )
 
   startwidget = new ButtonWidget( IW_WIDGET_START_NEW, w/2 + 5,
                 levwidget->TopEdge() + levwidget->Height() - sfont->Height() - 8,
-                w/2 - 10, sfont->Height() + 8, 's',
-                WIDGET_DEFAULT, "Start", this );
+                w/2 - 10, sfont->Height() + 8, WIDGET_DEFAULT,
+                "_Start", this );
   startwidget->SetHook( this );
 
   videowidget = new ButtonWidget( IW_WIDGET_VIDEO_OPTIONS,
                 startwidget->LeftEdge(), levwidget->TopEdge(),
                 startwidget->Width() - ICON_QUIT_W - 13, startwidget->Height(),
-                'v', 0, "Video Options", this );
+                0, "_Video Options", this );
   videowidget->SetHook( this );
 
   listctrlwidget = new ButtonWidget( IW_WIDGET_LOAD_SAVED, startwidget->LeftEdge(),
                    videowidget->TopEdge() + videowidget->Height() + 5,
-                   startwidget->Width(), videowidget->Height(), 'l', 0,
-                   "Load saved game", this );
+                   startwidget->Width(), videowidget->Height(), 0,
+                   "_Load saved game", this );
   listctrlwidget->SetHook( this );
 
   pbemwidget = new CheckboxWidget( IW_WIDGET_PBEM, listctrlwidget->LeftEdge() + 5,
                    listctrlwidget->TopEdge() + listctrlwidget->Height() + 10,
-                   DEFAULT_CBW_SIZE, DEFAULT_CBW_SIZE, CFOptions.GetPBEM(), 'e',
+                   DEFAULT_CBW_SIZE, DEFAULT_CBW_SIZE, CFOptions.GetPBEM(),
                    WIDGET_STYLE_NOBORDER|WIDGET_STYLE_GFX|WIDGET_ALIGN_RIGHT|
                    (CFOptions.GetComputerPlayer() ? WIDGET_DISABLED : 0),
-                   "Play By e-Mail", this );
+                   "Play By _e-Mail", this );
   pbemwidget->SetHook( this );
 
   aiwidget = new CheckboxWidget( IW_WIDGET_AI, pbemwidget->LeftEdge(),
                    pbemwidget->TopEdge() + pbemwidget->Height() + 3,
                    DEFAULT_CBW_SIZE, DEFAULT_CBW_SIZE, CFOptions.GetComputerPlayer(),
-                   'c', WIDGET_STYLE_NOBORDER|WIDGET_STYLE_GFX|WIDGET_ALIGN_RIGHT|
+                   WIDGET_STYLE_NOBORDER|WIDGET_STYLE_GFX|WIDGET_ALIGN_RIGHT|
                    (CFOptions.GetPBEM() ? WIDGET_DISABLED : 0),
-                   "Play vs. Computer", this );
+                   "Play vs. _Computer", this );
   aiwidget->SetHook( this );
 
   // the quit button
   ButtonWidget *btn = new ButtonWidget( GUI_QUIT, w - ICON_QUIT_W - 9,
                    videowidget->TopEdge(), ICON_QUIT_W + 4, ICON_QUIT_H + 4,
-                   SDLK_ESCAPE, WIDGET_STYLE_GFX, NULL, this );
+                   WIDGET_STYLE_GFX, NULL, this );
+  btn->SetKey( SDLK_ESCAPE );
   btn->SetImage( view->GetSystemIcons(),
                    Rect( ICON_QUIT_X, ICON_QUIT_Y, ICON_QUIT_W, ICON_QUIT_H ),
                    Rect( ICON_QUIT_X, ICON_QUIT_Y, ICON_QUIT_W, ICON_QUIT_H ) );
@@ -439,9 +436,9 @@ VideoOptionsWindow::VideoOptionsWindow( View *view ) :
 
   fswidget = new CheckboxWidget( 0, modewidget->LeftEdge() + 10,
                    modewidget->TopEdge() + modewidget->Height() + 10,
-                   DEFAULT_CBW_SIZE, DEFAULT_CBW_SIZE, view->IsFullScreen(), 'f',
+                   DEFAULT_CBW_SIZE, DEFAULT_CBW_SIZE, view->IsFullScreen(),
                    WIDGET_STYLE_NOBORDER|WIDGET_STYLE_GFX|WIDGET_ALIGN_RIGHT,
-                   "Fullscreen", this );
+                   "_Fullscreen", this );
 
   Draw();
   Show();
@@ -559,7 +556,7 @@ GenericOptionsWindow::GenericOptionsWindow( unsigned short w,
        title(title) {
 
   Widget *wd = new ButtonWidget( B_ID_OK, 1, Height() - sfont->Height() - 9,
-                   Width() - 2, sfont->Height() + 8, 'o', WIDGET_DEFAULT, "OK", this );
+                   Width() - 2, sfont->Height() + 8, WIDGET_DEFAULT, "_OK", this );
   wd->SetHook( this );
 }
 
@@ -592,7 +589,7 @@ void GenericOptionsWindow::Draw( void ) {
 
 GeneralOptionsWindow::GeneralOptionsWindow( MapView &mv, View *view ) :
      GenericOptionsWindow( view->LargeFont()->Width() * 15 + 30,
-                           view->SmallFont()->Height() * 2 + 35,
+                           view->SmallFont()->Height() * 3 + 35,
                            "General Options", view ), mv(mv) {
   // create widgets
   const Rect &b = GetBounds();
@@ -600,13 +597,22 @@ GeneralOptionsWindow::GeneralOptionsWindow( MapView &mv, View *view ) :
   // damage indicator
   diwidget = new CheckboxWidget( 0, b.x + 5, b.y + 5,
                DEFAULT_CBW_SIZE, DEFAULT_CBW_SIZE, mv.UnitStatsEnabled(),
-               'd', WIDGET_STYLE_NOBORDER|WIDGET_STYLE_GFX|WIDGET_ALIGN_RIGHT,
-               "Show damage indicators", this );
+               WIDGET_STYLE_NOBORDER|WIDGET_STYLE_GFX|WIDGET_ALIGN_RIGHT,
+               "Show _damage indicators", this );
 
-  repwidget = new CheckboxWidget( 0, b.x + 5, b.y + + diwidget->Height() + 10,
+  // replay
+  repwidget = new CheckboxWidget( 0, b.x + 5, b.y + diwidget->Height() + 10,
               DEFAULT_CBW_SIZE, DEFAULT_CBW_SIZE, CFOptions.GetTurnReplay(),
-              't', WIDGET_STYLE_NOBORDER|WIDGET_STYLE_GFX|WIDGET_ALIGN_RIGHT,
-              "Show turn replays", this );
+              WIDGET_STYLE_NOBORDER|WIDGET_STYLE_GFX|WIDGET_ALIGN_RIGHT,
+              "Show _turn replays", this );
+  repwidget->SetHook(this);
+
+  // quick replays
+  qrepwidget = new CheckboxWidget( 0, b.x + 15, repwidget->y + repwidget->Height() + 5,
+              DEFAULT_CBW_SIZE, DEFAULT_CBW_SIZE, CFOptions.GetQuickReplay(),
+              WIDGET_STYLE_NOBORDER|WIDGET_STYLE_GFX|WIDGET_ALIGN_RIGHT|
+              (repwidget->Clicked() ? 0 : WIDGET_DISABLED),
+              "Show _battle results only", this );
   Draw();
   Show();
 }
@@ -621,21 +627,37 @@ GeneralOptionsWindow::GeneralOptionsWindow( MapView &mv, View *view ) :
 ////////////////////////////////////////////////////////////////////////
 
 GUI_Status GeneralOptionsWindow::WidgetActivated( Widget *widget, Window *win ) {
-  view->CloseWindow( win );
 
-  if ( mv.UnitStatsEnabled() != diwidget->Clicked() ) {
-    CFOptions.SetDamageIndicator( diwidget->Clicked() );
+  if ( widget == repwidget ) {
 
-    if ( diwidget->Clicked() ) mv.EnableUnitStats();
-    else mv.DisableUnitStats();
+    if ( repwidget->Clicked() ) qrepwidget->Enable();
+    else {
+      qrepwidget->Release();
+      qrepwidget->Disable();
+    }
 
-    // now redraw the map display
-    mv.Draw();
-    view->Refresh( mv );
+    Draw();
+    Show();
+
+  } else {
+
+    view->CloseWindow( win );
+
+    if ( mv.UnitStatsEnabled() != diwidget->Clicked() ) {
+      CFOptions.SetDamageIndicator( diwidget->Clicked() );
+
+      if ( diwidget->Clicked() ) mv.EnableUnitStats();
+      else mv.DisableUnitStats();
+
+      // now redraw the map display
+      mv.Draw();
+      view->Refresh( mv );
+    }
+
+    CFOptions.SetTurnReplay( repwidget->Clicked() );
+    CFOptions.SetQuickReplay( qrepwidget->Clicked() );
   }
 
-  CFOptions.SetTurnReplay( repwidget->Clicked() );
-
   return GUI_OK;
 }
 
@@ -648,6 +670,11 @@ GUI_Status GeneralOptionsWindow::WidgetActivated( Widget *widget, Window *win )
 
 #ifndef DISABLE_SOUND
 
+const short SoundOptionsWindow::B_ID_SFX       = 10;
+const short SoundOptionsWindow::B_ID_MUSIC     = 11;
+const short SoundOptionsWindow::S_ID_VOL_SFX   = 12;
+const short SoundOptionsWindow::S_ID_VOL_MUSIC = 13;
+
 SoundOptionsWindow::SoundOptionsWindow( View *view ) :
      GenericOptionsWindow( view->LargeFont()->Width() * 13 + 30,
                            view->SmallFont()->Height() * 2 + 20,
@@ -660,8 +687,8 @@ SoundOptionsWindow::SoundOptionsWindow( View *view ) :
   // sfx
   wd = new CheckboxWidget( B_ID_SFX, b.x + 5, b.y + 5,
            DEFAULT_CBW_SIZE, DEFAULT_CBW_SIZE, Audio::GetSfxState(),
-           's', WIDGET_STYLE_NOBORDER|WIDGET_STYLE_GFX|WIDGET_ALIGN_RIGHT,
-           "SFX", this );
+           WIDGET_STYLE_NOBORDER|WIDGET_STYLE_GFX|WIDGET_ALIGN_RIGHT,
+           "_SFX", this );
   wd->SetHook( this );
 
   // sfx volume
@@ -670,7 +697,7 @@ SoundOptionsWindow::SoundOptionsWindow( View *view ) :
   sfxvol = new SliderWidget( S_ID_VOL_SFX,
            xoff, wd->TopEdge() + (wd->Height() - DEFAULT_SLIDER_SIZE)/2,
            b.w - xoff - 5, DEFAULT_SLIDER_SIZE, 0, MIX_MAX_VOLUME,
-           Audio::GetSfxVolume(), 20, 'f',
+           Audio::GetSfxVolume(), 20,
            WIDGET_HSCROLL|WIDGET_HSCROLLKEY|
              (Audio::GetSfxState() ? 0 : WIDGET_DISABLED),
            NULL, this );
@@ -679,16 +706,16 @@ SoundOptionsWindow::SoundOptionsWindow( View *view ) :
   // music
   wd = new CheckboxWidget( B_ID_MUSIC,
            wd->LeftEdge(), wd->TopEdge() + wd->Height() + 5,
-           DEFAULT_CBW_SIZE, DEFAULT_CBW_SIZE, Audio::GetMusicState(), 'm',
+           DEFAULT_CBW_SIZE, DEFAULT_CBW_SIZE, Audio::GetMusicState(),
            WIDGET_STYLE_NOBORDER|WIDGET_STYLE_GFX|WIDGET_ALIGN_RIGHT|WIDGET_DISABLED,
-           "Music", this );
+           "_Music", this );
   wd->SetHook( this );
 
   // music volume
   musicvol = new SliderWidget( S_ID_VOL_MUSIC,
            xoff, wd->TopEdge() + (wd->Height() - DEFAULT_SLIDER_SIZE)/2,
            b.w - xoff - 5, DEFAULT_SLIDER_SIZE, 0, MIX_MAX_VOLUME,
-           0, 20, 'u', WIDGET_HSCROLL|WIDGET_VSCROLLKEY|WIDGET_DISABLED,
+           0, 20, WIDGET_HSCROLL|WIDGET_VSCROLLKEY|WIDGET_DISABLED,
            NULL, this );
   musicvol->SetHook( this );
 
