@@ -309,8 +309,11 @@ void load_settings( GUIOptions &opts ) {
           else if ( !strncmp( linebuf, "sfx", 3 ) ) opts.sfx = (atoi(val) != 0);
           else if ( !strncmp( linebuf, "music", 5 ) ) opts.music = (atoi(val) != 0);
           else if ( !strncmp( linebuf, "showdamage", 10 ) ) CFOptions.SetDamageIndicator( atoi(val) != 0 );
-          else if ( !strncmp( linebuf, "showreplay", 10 ) ) CFOptions.SetTurnReplay( atoi(val) != 0 );
-          else fprintf( stderr, "warning: unrecognized config option in line %d\n", linecnt );
+          else if ( !strncmp( linebuf, "showreplay", 10 ) ) {
+            int rep = atoi(val);
+            CFOptions.SetTurnReplay( rep != 0 );
+            CFOptions.SetQuickReplay( rep == 1 );
+          } else fprintf( stderr, "warning: unrecognized config option in line %d\n", linecnt );
         }
       }
     }
@@ -339,7 +342,8 @@ void save_settings( View *display ) {
     fprintf( fp, "sfxvol %d\n", Audio::GetSfxVolume() );
     fprintf( fp, "musicvol %d\n", Audio::GetMusicVolume() );
     fprintf( fp, "showdamage %d\n", CFOptions.GetDamageIndicator() );
-    fprintf( fp, "showreplay %d\n", CFOptions.GetTurnReplay() );
+    fprintf( fp, "showreplay %d\n",
+      CFOptions.GetTurnReplay() ? (CFOptions.GetQuickReplay() ? 1 : 2) : 0 );
     fclose( fp );
   }
 }
