@@ -1,5 +1,5 @@
 // Crimson Fields -- a game of tactical warfare
-// Copyright (C) 2000-2003 Jens Granseuer
+// Copyright (C) 2000-2004 Jens Granseuer
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -492,8 +492,8 @@ TacticalWindow::TacticalWindow( MapView *mapview, View *view ) :
   CalcViewPort( viewport );
 
   new ButtonWidget( GUI_CLOSE, 1, h - sfont->Height() - 9,
-                    w - 2, sfont->Height() + 8, 'o',
-                    WIDGET_DEFAULT, "OK", this );
+                    w - 2, sfont->Height() + 8,
+                    WIDGET_DEFAULT, "_OK", this );
 
   mw = new MapWidget( 0, map.x, map.y, map.w, map.h,
                       WIDGET_HSCROLLKEY|WIDGET_VSCROLLKEY, this );
