@@ -31,23 +31,26 @@
 class Options {
 public:
   Options( void ) : ai(true), pbem(false), show_damage(true),
-                    replay(true) {}
+                    replay(true), quick_replay(false) {}
 
   void SetComputerPlayer( bool cp ) { ai = cp; }
   void SetPBEM( bool mail ) { pbem = mail; }
   void SetDamageIndicator( bool di ) { show_damage = di; }
   void SetTurnReplay( bool rep ) { replay = rep; }
+  void SetQuickReplay( bool rep ) { quick_replay = rep; }
 
   bool GetComputerPlayer( void ) { return ai; }
   bool GetPBEM( void ) { return pbem; }
   bool GetDamageIndicator( void ) { return show_damage; }
   bool GetTurnReplay( void ) { return replay; }
+  bool GetQuickReplay( void ) { return quick_replay; }
 
 private:
   bool ai;            // play against computer
   bool pbem;          // play by email
   bool show_damage;   // show damage indicator
   bool replay;        // show turn replays
+  bool quick_replay;  // show only combat results
 };
 
 #endif	/* _INCLUDE_OPTIONS_H */
