@@ -1,5 +1,5 @@
 // Crimson Fields -- a game of tactical warfare
-// Copyright (C) 2000-2003 Jens Granseuer
+// Copyright (C) 2000-2004 Jens Granseuer
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -265,7 +265,7 @@ ContainerWindow::ContainerWindow( UnitContainer *container, View *view ) :
   // create buttons
   Surface *icons = view->GetSystemIcons();
   new ButtonWidget( GUI_CLOSE, 10, h - sfont->Height() - 18,
-      width, sfont->Height() + 8, 'x', WIDGET_DEFAULT, "Exit", this );
+      width, sfont->Height() + 8, WIDGET_DEFAULT, "E_xit", this );
 
   if ( c->Owner() == Gam->CurrentPlayer() ) {
     ButtonWidget *btn;
@@ -274,12 +274,13 @@ ContainerWindow::ContainerWindow( UnitContainer *container, View *view ) :
     if ( (unit && t->IsMedic()) ||
          (!unit && b->IsWorkshop()) ) {
       btn = new ButtonWidget( CH_BUTTON_REPAIR, xoff, yoff,
-                     ICON_MINI_WIDTH + 4, ICON_MINI_HEIGHT + 4, 'r',
+                     ICON_MINI_WIDTH + 4, ICON_MINI_HEIGHT + 4,
                      WIDGET_STYLE_GFX, NULL, this );
       btn->SetImage( icons, Rect( ICON_MINI_REPAIR1_X, ICON_MINI_REPAIR1_Y,
                                   ICON_MINI_WIDTH, ICON_MINI_HEIGHT ),
                             Rect( ICON_MINI_REPAIR2_X, ICON_MINI_REPAIR2_Y,
                                   ICON_MINI_WIDTH, ICON_MINI_HEIGHT ) );
+      btn->SetKey( 'r' );
       btn->SetHook( this );
       xoff += btn->Width();
       buttons[CH_BUTTON_REPAIR] = btn;
@@ -288,12 +289,13 @@ ContainerWindow::ContainerWindow( UnitContainer *container, View *view ) :
     if ( !unit ) {
       if ( b->IsFactory() && (b->UnitProduction() != 0) ) {
         btn = new ButtonWidget( CH_BUTTON_BUILD, xoff, yoff,
-                       ICON_MINI_WIDTH + 4, ICON_MINI_HEIGHT + 4, 'b',
+                       ICON_MINI_WIDTH + 4, ICON_MINI_HEIGHT + 4,
                        WIDGET_STYLE_GFX, NULL, this );
         btn->SetImage( icons, Rect( ICON_MINI_BUILD1_X, ICON_MINI_BUILD1_Y,
                                     ICON_MINI_WIDTH, ICON_MINI_HEIGHT ),
                               Rect( ICON_MINI_BUILD2_X, ICON_MINI_BUILD2_Y,
                                     ICON_MINI_WIDTH, ICON_MINI_HEIGHT ) );
+        btn->SetKey( 'b' );
         btn->SetHook( this );
         xoff += btn->Width();
         buttons[CH_BUTTON_BUILD] = btn;
@@ -301,12 +303,13 @@ ContainerWindow::ContainerWindow( UnitContainer *container, View *view ) :
     }
 
     btn = new ButtonWidget( CH_BUTTON_TRANSFER, xoff, yoff,
-                  ICON_MINI_WIDTH + 4, ICON_MINI_HEIGHT + 4, 't',
-                   WIDGET_STYLE_GFX, NULL, this );
+                  ICON_MINI_WIDTH + 4, ICON_MINI_HEIGHT + 4,
+                  WIDGET_STYLE_GFX, NULL, this );
     btn->SetImage( icons, Rect( ICON_MINI_TRANSFER1_X, ICON_MINI_TRANSFER1_Y,
                                 ICON_MINI_WIDTH, ICON_MINI_HEIGHT ),
                           Rect( ICON_MINI_TRANSFER2_X, ICON_MINI_TRANSFER2_Y,
                                 ICON_MINI_WIDTH, ICON_MINI_HEIGHT ) );
+    btn->SetKey( 't' );
     btn->SetHook( this );
     buttons[CH_BUTTON_TRANSFER] = btn;
   }
@@ -473,16 +476,16 @@ void ContainerWindow::SwitchMode( unsigned short newmode ) {
     slider = new SliderWidget( 0, unitinfo.x + GFX_WIDTH + 20,
                                unitinfo.y + (unitinfo.h - DEFAULT_SLIDER_SIZE) / 2,
                                unitinfo.w - 2 * ICON_WIDTH - 40, DEFAULT_SLIDER_SIZE,
-                               min, max, fullhost, max - min + 1, 0,
+                               min, max, fullhost, max - min + 1,
                                WIDGET_HSCROLL|WIDGET_HSCROLLKEY|WIDGET_VSCROLLKEY,
                                NULL, this );
     stringwidgets[0] = new StringWidget( 0, unitinfo.x + 10,
                                unitinfo.y + unitinfo.h / 2, sfont->Width() * 4 + 8,
-                               sfont->Height() + 8, 0, itoa( fullclient, buf ), 4,
+                               sfont->Height() + 8, itoa( fullclient, buf ), 4,
                                WIDGET_ALIGN_CENTER|WIDGET_STR_CONST, NULL, this );
     stringwidgets[1] = new StringWidget( 0, slider->LeftEdge() + slider->Width() + 10,
                                unitinfo.y + unitinfo.h / 2, sfont->Width() * 4 + 8,
-                               sfont->Height() + 8, 0, itoa( fullhost, buf ), 4,
+                               sfont->Height() + 8, itoa( fullhost, buf ), 4,
                                WIDGET_ALIGN_CENTER|WIDGET_STR_CONST, NULL, this );
     transferscroll = new TransferScrollable( fullhost, fullclient, stringwidgets[1],
                                stringwidgets[0], c, t );
@@ -604,7 +607,7 @@ GUI_Status ContainerWindow::WidgetActivated( Widget *widget, Window *win ) {
         sprintf( repmsg, "Repairing the %s requires %d crystals.", u->Name(), CRYSTALS_REPAIR );
 
         if ( c->Crystals() >= CRYSTALS_REPAIR ) {
-          DialogWindow *reqwin = new DialogWindow( NULL, repmsg, "rRepair|cCancel",
+          DialogWindow *reqwin = new DialogWindow( NULL, repmsg, "_Repair|_Cancel",
                                                    0, 0, view );
           reqwin->SetButtonID( 0, CH_BUTTON_REPAIR_CONFIRM );
           reqwin->SetButtonHook( 0, this );
