@@ -37,7 +37,7 @@ public:
 
   bool IsWorkshop( void ) const { return (b_flags & BLD_WORKSHOP) != 0; }
   bool IsFactory( void ) const { return (b_flags & BLD_FACTORY) != 0; }
-  bool IsMine( void ) const { return (b_flags & BLD_MINE) != 0; }
+  bool IsMine( void ) const { return CrystalProduction() > 0; }
 
   unsigned char CrystalProduction( void ) const { return b_cprod; }
   unsigned short Crystals( void ) const { return b_crystals; }
