@@ -1,5 +1,5 @@
 // CoMET - The Crimson Fields Map Editing Tool
-// Copyright (C) 2002-2003 Jens Granseuer
+// Copyright (C) 2002-2004 Jens Granseuer
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -88,11 +88,11 @@ EdWindow::EdWindow( const string &mapdir, View *view ) :
   tile_wd->SetHook( this );
 
   ud_wd = new SliderWidget( S_ID_VERT, 0, 0, DEFAULT_SLIDER_SIZE, mv.Height(),
-                            0, 0, 0, 1, 0, WIDGET_VSCROLL, NULL, this );
+                            0, 0, 0, 1, WIDGET_VSCROLL, NULL, this );
   ud_wd->SetHook( this );
   lr_wd = new SliderWidget( S_ID_HORIZ, DEFAULT_SLIDER_SIZE, h - DEFAULT_SLIDER_SIZE,
                             mv.Width(), DEFAULT_SLIDER_SIZE,
-                            0, 0, 0, 1, 0, WIDGET_HSCROLL, NULL, this );
+                            0, 0, 0, 1, WIDGET_HSCROLL, NULL, this );
   lr_wd->SetHook( this );
 }
 
@@ -516,7 +516,7 @@ string EdWindow::GetFileName( const char *filename, const char *suffix,
       char *conmsg = new char[ file.length() + 20 ];
       strcpy( conmsg, file.c_str() );
       strcat( conmsg, " exists. Overwrite?" );
-      dw = new DialogWindow( NULL, conmsg, "yYes|nNo", 1, 0, view );
+      dw = new DialogWindow( NULL, conmsg, "_Yes|_No", 1, 0, view );
       dw->SetButtonID( 0, 1 );
       dw->SetButtonID( 1, 0 );
       rc = dw->EventLoop();
@@ -672,7 +672,7 @@ GUI_Status EdWindow::WidgetActivated( Widget *widget, Window *win ) {
 
 void EdWindow::Quit( void ) const {
   DialogWindow *req = new DialogWindow( NULL, "Do you really want to quit?",
-                                        "yYes|nNo", 1, 0, view );
+                                        "_Yes|_No", 1, 0, view );
   req->SetButtonID( 0, GUI_QUIT );
 }
 
@@ -694,47 +694,47 @@ void EdWindow::ShowContextMenu( const Point &clicked ) {
       selected_hex = clicked;
 
       // tile sub-menu
-      menu->AddMenu( 0, 0, "Tile", 't' );
-      menu->AddItem( 1, B_ID_TILE_GRAB, 0, "Grab", 'g' );
+      menu->AddMenu( 0, 0, "_Tile" );
+      menu->AddItem( 1, B_ID_TILE_GRAB, 0, "_Grab" );
       menu->AddItem( 1, B_ID_TILE_SWAP,
                      (mode == ED_MODE_TERRAIN ? 0 : WIDGET_DISABLED),
-                     "Swap", 's' );
+                     "_Swap" );
 
       if ( u ) {  // unit sub-menu
-        menu->AddMenu( 0, 0, "Unit", 'u' );
-        menu->AddItem( 1, B_ID_UNIT_INFO, WIDGET_DISABLED, "Info", 'i' );  // FIXME
-        menu->AddItem( 1, B_ID_UNIT_EDIT, 0, "Edit...", 'e' );
-        menu->AddItem( 1, B_ID_UNIT_DEL, 0, "Delete", 'd' );
+        menu->AddMenu( 0, 0, "_Unit" );
+        menu->AddItem( 1, B_ID_UNIT_INFO, WIDGET_DISABLED, "_Info" );  // FIXME
+        menu->AddItem( 1, B_ID_UNIT_EDIT, 0, "_Edit..." );
+        menu->AddItem( 1, B_ID_UNIT_DEL, 0, "_Delete" );
       }
 
       if ( map->IsBuilding( clicked ) ) {
         Building *b = map->GetBuilding( clicked );
 
-        menu->AddMenu( 0, 0, "Building", 'b' );
+        menu->AddMenu( 0, 0, "_Building" );
         if ( b ) {
-          menu->AddItem( 1, B_ID_BLD_EDIT,  0, "Edit...", 'e' );
-          menu->AddItem( 1, B_ID_BLD_DEL,   0, "Delete", 'd' );
-        } else menu->AddItem( 1, B_ID_BLD_CREATE, 0, "Create...", 'c' );
+          menu->AddItem( 1, B_ID_BLD_EDIT,  0, "_Edit..." );
+          menu->AddItem( 1, B_ID_BLD_DEL,   0, "_Delete" );
+        } else menu->AddItem( 1, B_ID_BLD_CREATE, 0, "_Create..." );
       }
     }
 
-    menu->AddItem( 0, B_ID_EVENTS, 0, "Events...", 'e' );
+    menu->AddItem( 0, B_ID_EVENTS, 0, "_Events..." );
     menu->AddBar( 0 );
   }
 
   // file ops
-  menu->AddMenu( 0, 0, "Project", 'p' );
-  menu->AddItem( 1, B_ID_NEW, 0, "New...", 'n' );
-  menu->AddItem( 1, B_ID_LOAD, 0, "Load...", 'l' );
+  menu->AddMenu( 0, 0, "_Project" );
+  menu->AddItem( 1, B_ID_NEW, 0, "_New..." );
+  menu->AddItem( 1, B_ID_LOAD, 0, "_Load..." );
   menu->AddItem( 1, B_ID_SAVE, (mission ? 0 : WIDGET_DISABLED),
-                 "Save...", 's' );
+                 "_Save..." );
   menu->AddItem( 1, B_ID_EXPORT, (mission ? 0 : WIDGET_DISABLED),
-                 "Export...", 'x' );
+                 "_Export..." );
   menu->AddItem( 1, B_ID_VALIDATE, (mission ? 0 : WIDGET_DISABLED),
-                 "Validate", 'v' );
+                 "_Validate" );
   menu->AddItem( 1, B_ID_SETTINGS, (mission ? 0 : WIDGET_DISABLED),
-                 "Settings", 't' );
-  menu->AddItem( 1, B_ID_QUIT, 0, "Quit...", 'q' );
+                 "Se_ttings" );
+  menu->AddItem( 1, B_ID_QUIT, 0, "_Quit..." );
 
   menu->Layout();
 }
