@@ -1,5 +1,5 @@
 // CoMET - The Crimson Fields Map Editing Tool
-// Copyright (C) 2002-2003 Jens Granseuer
+// Copyright (C) 2002-2004 Jens Granseuer
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -104,28 +104,28 @@ EdEventGenericWindow::EdEventGenericWindow( Event &event,
   char buf[48] = "";
 
   wd = new NumberWidget( 0, sfont->Width() * 2 + 10, wdy,
-       sfont->Width() * 6, wdh, 0, event.ID(),
+       sfont->Width() * 6, wdh, event.ID(),
        0, 32767, WIDGET_STR_CONST|WIDGET_ALIGN_LEFT, "ID", this );
 
   wdx = wd->LeftEdge() + wd->Width() + sfont->Width() * 6 + 10;
   wd = new CycleWidget( B_ID_PLAYER, wdx, wdy, w - wdx - 5, wdh,
-       'p', 0, "Player", event.Player(), player2_labels, this );
+       0, "_Player", event.Player(), player2_labels, this );
   wd->SetHook( this );
 
   wdy += wd->Height() + 5;
   wd = new ButtonWidget( B_ID_TITLE, 5, wdy,
-       sfont->Width() * 9 + 10, wdh, 't', 0, "Msg Title", this );
+       sfont->Width() * 9 + 10, wdh, 0, "Msg _Title", this );
   wd->SetHook( this );
 
   wdx = wd->LeftEdge() + wd->Width() + 5;
-  e_title = new StringWidget( 0, wdx, wdy, w - wdx - 5, wdh, 0,
+  e_title = new StringWidget( 0, wdx, wdy, w - wdx - 5, wdh,
             (mission.GetMessage(event.Title()) ?
              mission.GetMessage(event.Title()) : ""),
             30, WIDGET_STR_CONST, NULL, this );
 
   wdy += wd->Height() + 5;
   wd = new ButtonWidget( B_ID_MSG, 5, wdy, w - 10, wdh,
-       'm', 0, "Set Event Message", this );
+       0, "Set Event _Message", this );
   wd->SetHook( this );
 
   wdy += wd->Height() + 5;
@@ -136,19 +136,19 @@ EdEventGenericWindow::EdEventGenericWindow( Event &event,
 
   wdy += e_msg->Height() + 5;
   wd = new ButtonWidget( B_ID_TRIGGER, 5, wdy,
-       sfont->Width() * 12 + 10, wdh, 'r', 0,
-       "Edit Trigger", this );
+       sfont->Width() * 12 + 10, wdh, 0,
+       "Edit T_rigger", this );
   wd->SetHook( this );
 
   wdy += wd->Height() + 5;
   wd = new ButtonWidget( B_ID_EVENT, 5, wdy, wd->Width(), wdh,
-       'e', (event.Type() == EVENT_MESSAGE) ? WIDGET_DISABLED : 0,
-       "Edit Event", this );
+       (event.Type() == EVENT_MESSAGE) ? WIDGET_DISABLED : 0,
+       "Edit _Event", this );
   wd->SetHook( this );
 
   wdy += wd->Height() + 5;
   wd = new ButtonWidget( B_ID_DEPEND, 5, wdy, wd->Width(), wdh,
-       'd', 0, "Depends on", this );
+       0, "_Depends on", this );
   wd->SetHook( this );
 
   wdx = wd->LeftEdge() + wd->Width() + 5;
@@ -157,10 +157,10 @@ EdEventGenericWindow::EdEventGenericWindow( Event &event,
     if ( e ) sprintf( buf, "%s (%d)", e->Name(), e->ID() );
   }
   e_depends = new StringWidget( 0, wdx, wdy, w - wdx - 5, wdh,
-              0, buf, 47, WIDGET_STR_CONST, NULL, this );
+              buf, 47, WIDGET_STR_CONST, NULL, this );
 
   new ButtonWidget( GUI_CLOSE, 1, h - wdh - 1, w - 2, wdh,
-                    'o', WIDGET_DEFAULT, "OK", this );
+                    WIDGET_DEFAULT, "_OK", this );
 
   Draw();
   Show();
@@ -300,25 +300,25 @@ EdEventCreateUnitWindow::EdEventCreateUnitWindow( Event &event,
   unsigned short wdx, wdh = sfont->Height() + 8;
 
   wd = new ButtonWidget( B_ID_UNIT, 5, 5,
-       sfont->Width() * 4 + 10, wdh, 'u', 0, "Unit", this );
+       sfont->Width() * 4 + 10, wdh, 0, "_Unit", this );
   wd->SetHook( this );
 
   wdx = wd->LeftEdge() + wd->Width() + 5;
-  e_unit = new StringWidget( 0, wdx, 5, w - wdx - 5, wdh, 0,
+  e_unit = new StringWidget( 0, wdx, 5, w - wdx - 5, wdh,
            mission.GetUnitSet().GetUnitInfo(event.GetData(0))->Name(),
            30, WIDGET_STR_CONST, NULL, this );
 
   wd = new ButtonWidget( B_ID_SHOP, 5, wd->TopEdge() + wdh + 5,
-       sfont->Width() * 4 + 10, wdh, 's', 0, "Shop", this );
+       sfont->Width() * 4 + 10, wdh, 0, "_Shop", this );
   wd->SetHook( this );
 
   Building *b = mission.GetBuildingByID( event.GetData(1) );
   e_shop = new StringWidget( 0, wdx, wd->TopEdge(),
-           e_unit->Width(), wdh, 0, b ? b->Name() : "Error",
+           e_unit->Width(), wdh, b ? b->Name() : "Error",
            30, WIDGET_STR_CONST, NULL, this );
 
-  new ButtonWidget( GUI_CLOSE, 1, h - wdh - 1, w - 2, wdh, 'o',
-                    WIDGET_DEFAULT, "OK", this );
+  new ButtonWidget( GUI_CLOSE, 1, h - wdh - 1, w - 2, wdh,
+                    WIDGET_DEFAULT, "_OK", this );
 
   Draw();
   Show();
@@ -387,19 +387,19 @@ EdEventManipEventWindow::EdEventManipEventWindow( Event &event,
   char buf[48] = "Error";
 
   wd = new ButtonWidget( B_ID_EVENT, 5, 5,
-       sfont->Width() * 5 + 10, wdh, 'e', 0, "Event", this );
+       sfont->Width() * 5 + 10, wdh, 0, "_Event", this );
   wd->SetHook( this );
 
   Event *e = mission.GetEventByID( event.GetData(0) );
   if ( e ) sprintf( buf, "%s (%d)", e->Name(), e->ID() );
   wdx = wd->LeftEdge() + wd->Width() + 5;
   e_event = new StringWidget( 0, wdx, 5, w - wdx - 5, wdh,
-            0, buf, 30, WIDGET_STR_CONST, NULL, this );
+            buf, 30, WIDGET_STR_CONST, NULL, this );
 
   wdx = sfont->Width() * 6 + 10;
   wdy = wdh + 10;
   wd = new CycleWidget( B_ID_ACTION, wdx, wdy,
-       w - wdx - 5, wdh, 'a', 0, "Action",
+       w - wdx - 5, wdh, 0, "_Action",
        event.GetData(2), action_labels, this );
   wd->SetHook( this );
 
@@ -407,13 +407,13 @@ EdEventManipEventWindow::EdEventManipEventWindow( Event &event,
   wdy += wdh + 5;
   wd = new CheckboxWidget( B_ID_DISABLED, wdx, wdy,
        DEFAULT_CBW_SIZE, DEFAULT_CBW_SIZE,
-       event.GetData(1) & EFLAG_DISABLED, 'd',
+       event.GetData(1) & EFLAG_DISABLED,
        WIDGET_STYLE_GFX|WIDGET_STYLE_NOBORDER|WIDGET_ALIGN_LEFT,
-       "Disabled", this );
+       "_Disabled", this );
   wd->SetHook( this );
 
-  new ButtonWidget( GUI_CLOSE, 1, h - wdh - 1, w - 2, wdh, 'o',
-                    WIDGET_DEFAULT, "OK", this );
+  new ButtonWidget( GUI_CLOSE, 1, h - wdh - 1, w - 2, wdh,
+                    WIDGET_DEFAULT, "_OK", this );
   Draw();
   Show();
 
@@ -474,26 +474,26 @@ EdEventMiningWindow::EdEventMiningWindow( Event &event,
   unsigned short wdx, wdy, wdh = sfont->Height() + 8;
 
   wd = new ButtonWidget( B_ID_MINE, 5, 5,
-       sfont->Width() * 6, wdh, 'm', 0, "Mine", this );
+       sfont->Width() * 6, wdh, 0, "_Mine", this );
   wd->SetHook( this );
 
   wdx = wd->LeftEdge() + wd->Width() + 5;
   Building *b = mission.GetBuildingByID( event.GetData(0) );
   e_mine = new StringWidget( 0, wdx, wd->TopEdge(),
-           w - wdx - 5, wdh, 0, b ? b->Name() : "Error",
+           w - wdx - 5, wdh, b ? b->Name() : "Error",
            30, WIDGET_STR_CONST, NULL, this );
 
   wdy = wd->Height() + 10;
   wd = new CycleWidget( B_ID_ACTION, wdx, wdy,
-       e_mine->Width(), wdh, 'a', 0, "Action",
+       e_mine->Width(), wdh, 0, "_Action",
        event.GetData(2), action_labels, this );
   wd->SetHook( this );
 
   wdy += wdh + 5;
   e_crystals = new NumberWidget( N_ID_CRYSTALS,
-       wdx, wdy, wd->Width(), wdh, 'n',
+       wdx, wdy, wd->Width(), wdh,
        event.GetData(1), -1000, 10000,
-       WIDGET_ALIGN_LEFT, "Amount", this );
+       WIDGET_ALIGN_LEFT, "Amou_nt", this );
   e_crystals->SetHook( this );
 
   // this is kind of a hack: it's not (yet) possible to
@@ -502,8 +502,8 @@ EdEventMiningWindow::EdEventMiningWindow( Event &event,
   // the real values now
   SetMiningRange( event.GetData(1) );
 
-  new ButtonWidget( GUI_CLOSE, 1, h - wdh - 1, w - 2, wdh, 'o',
-                    WIDGET_DEFAULT, "OK", this );
+  new ButtonWidget( GUI_CLOSE, 1, h - wdh - 1, w - 2, wdh,
+                    WIDGET_DEFAULT, "_OK", this );
   Draw();
   Show();
 }
@@ -580,18 +580,18 @@ EdEventNextMapWindow::EdEventNextMapWindow( Event &event,
 
   unsigned short wdh = sfont->Height() + 8, wdx;
   Widget *wd = new ButtonWidget( B_ID_MAP, 5, 5,
-       sfont->Width() * 7 + 10, wdh, 'm', 0, "Mission", this );
+       sfont->Width() * 7 + 10, wdh, 0, "_Mission", this );
   wd->SetHook( this );
 
   wdx = wd->LeftEdge() + wd->Width() + 5;
   e_map = new StringWidget( 0, wdx, wd->TopEdge(),
-           w - wdx - 5, wdh, 0,
+           w - wdx - 5, wdh,
            mission.GetMessage(event.GetData(0)) ?
            mission.GetMessage(event.GetData(0)) : "None",
            30, WIDGET_STR_CONST, NULL, this );
 
   new ButtonWidget( GUI_CLOSE, 1, h - wdh - 1, w - 2, wdh,
-                    'o', WIDGET_DEFAULT, "OK", this );
+                    WIDGET_DEFAULT, "_OK", this );
   Draw();
   Show();
 }
@@ -639,26 +639,26 @@ EdEventResearchWindow::EdEventResearchWindow( Event &event,
   unsigned short wdx, wdh = sfont->Height() + 8;
 
   wd = new ButtonWidget( B_ID_SHOP, 5, 5,
-       sfont->Width() * 4 + 10, wdh, 's', 0, "Shop", this );
+       sfont->Width() * 4 + 10, wdh, 0, "_Shop", this );
   wd->SetHook( this );
 
   Building *b = mission.GetBuildingByID( event.GetData(0) );
   wdx = wd->LeftEdge() + wd->Width() + 5;
-  e_shop = new StringWidget( 0, wdx, 5, w - wdx - 5, wdh, 0,
+  e_shop = new StringWidget( 0, wdx, 5, w - wdx - 5, wdh,
            b ? b->Name() : "Error", 30, WIDGET_STR_CONST,
            NULL, this );
 
   wd = new ButtonWidget( B_ID_UNIT, 5, wd->TopEdge() + wdh + 5,
-       wd->Width(), wdh, 'u', 0, "Unit", this );
+       wd->Width(), wdh, 0, "_Unit", this );
   wd->SetHook( this );
 
   e_unit = new StringWidget( 0, wdx, wd->TopEdge(),
-           e_shop->Width(), wdh, 0,
+           e_shop->Width(), wdh,
            mission.GetUnitSet().GetUnitInfo(event.GetData(1))->Name(),
            30, WIDGET_STR_CONST, NULL, this );
 
-  new ButtonWidget( GUI_CLOSE, 1, h - wdh - 1, w - 2, wdh, 'o',
-                    WIDGET_DEFAULT, "OK", this );
+  new ButtonWidget( GUI_CLOSE, 1, h - wdh - 1, w - 2, wdh,
+                    WIDGET_DEFAULT, "_OK", this );
   Draw();
   Show();
 }
@@ -716,13 +716,13 @@ EdEventScoreWindow::EdEventScoreWindow( Event &event, View *view ) :
 
   unsigned short wdx = sfont->Width() * 5 + 10;
   Widget *wd = new NumberWidget( 0, wdx, 5,
-               w - wdx - 5, sfont->Height() + 8, 's',
+               w - wdx - 5, sfont->Height() + 8,
                event.GetData(0), 1, 100,
-               WIDGET_ALIGN_LEFT, "Score", this );
+               WIDGET_ALIGN_LEFT, "_Score", this );
   wd->SetHook( this );
 
   new ButtonWidget( GUI_CLOSE, 1, h - wd->Height() - 1, w - 2, wd->Height(),
-                    'o', WIDGET_DEFAULT, "OK", this );
+                    WIDGET_DEFAULT, "_OK", this );
   Draw();
   Show();
 }
@@ -760,28 +760,29 @@ EdTrigHaveShopWindow::EdTrigHaveShopWindow( Event &event,
   unsigned short wdx, wdh = sfont->Height() + 8;
 
   wd = new ButtonWidget( B_ID_SHOP, 5, 5,
-       sfont->Width() * 4 + 10, wdh, 's', 0, "Shop", this );
+       sfont->Width() * 4 + 10, wdh, 0, "_Shop", this );
   wd->SetHook( this );
 
   Building *b = mission.GetBuildingByID( event.GetTData(0) );
   wdx = wd->LeftEdge() + wd->Width() + 5;
   t_shop = new StringWidget( 0, wdx, 5, w - wdx - 5, wdh,
-           0, b ? b->Name() : "Error", 30, WIDGET_STR_CONST,
+           b ? b->Name() : "Error", 30, WIDGET_STR_CONST,
            NULL, this );
 
   wdx = sfont->Width() * 20 + 10;
   wd = new CycleWidget( B_ID_PLAYER, wdx, wd->Height() + 10,
-       w - wdx - 5, wdh, 'p', 0, "Controlled by Player",
+       w - wdx - 5, wdh, 0, "Controlled by _Player",
        event.GetTData(1), player2_labels, this );
+  wd->SetHook( this );
 
   wd = new NumberWidget( N_ID_TURN,
        sfont->Width() * 7 + 10, wd->TopEdge() + wd->Height() + 5,
-       sfont->Width() * 6, wdh, 't', event.GetTData(2),
-       -1, 999, WIDGET_ALIGN_LEFT, "On Turn", this );
+       sfont->Width() * 6, wdh, event.GetTData(2),
+       -1, 999, WIDGET_ALIGN_LEFT, "On _Turn", this );
   wd->SetHook( this );
 
-  new ButtonWidget( GUI_CLOSE, 1, h - wdh - 1, w - 2, wdh, 'o',
-                    WIDGET_DEFAULT, "OK", this );
+  new ButtonWidget( GUI_CLOSE, 1, h - wdh - 1, w - 2, wdh,
+                    WIDGET_DEFAULT, "_OK", this );
 
   Draw();
   Show();
@@ -839,7 +840,7 @@ EdTrigHaveUnitWindow::EdTrigHaveUnitWindow( Event &event,
   char buf[32] = "Error";
 
   wd = new ButtonWidget( B_ID_UNIT, 5, 5,
-       sfont->Width() * 4 + 10, wdh, 'u', 0, "Unit", this );
+       sfont->Width() * 4 + 10, wdh, 0, "_Unit", this );
   wd->SetHook( this );
 
   Unit *u = mission.GetUnitByID( event.GetTData(0) );
@@ -847,21 +848,21 @@ EdTrigHaveUnitWindow::EdTrigHaveUnitWindow( Event &event,
 
   wdx = wd->LeftEdge() + wd->Width() + 5;
   t_unit = new StringWidget( 0, wdx, 5, w - wdx - 5, wdh,
-           0, buf, 30, WIDGET_STR_CONST, NULL, this );
+           buf, 30, WIDGET_STR_CONST, NULL, this );
 
   wdx = sfont->Width() * 20 + 10;
   wd = new CycleWidget( B_ID_PLAYER, wdx, wd->Height() + 10,
-       w - wdx - 5, wdh, 'p', 0, "Controlled by Player",
+       w - wdx - 5, wdh, 0, "Controlled by _Player",
        event.GetTData(1), player2_labels, this );
 
   wd = new NumberWidget( N_ID_TURN,
        sfont->Width() * 7 + 10, wd->TopEdge() + wd->Height() + 5,
-       sfont->Width() * 6, wdh, 't', event.GetTData(2),
-       -1, 999, WIDGET_ALIGN_LEFT, "On Turn", this );
+       sfont->Width() * 6, wdh, event.GetTData(2),
+       -1, 999, WIDGET_ALIGN_LEFT, "On _Turn", this );
   wd->SetHook( this );
 
-  new ButtonWidget( GUI_CLOSE, 1, h - wdh - 1, w - 2, wdh, 'o',
-                    WIDGET_DEFAULT, "OK", this );
+  new ButtonWidget( GUI_CLOSE, 1, h - wdh - 1, w - 2, wdh,
+                    WIDGET_DEFAULT, "_OK", this );
 
   Draw();
   Show();
@@ -915,12 +916,12 @@ EdTrigTurnWindow::EdTrigTurnWindow( Event &event, View *view ) :
   unsigned short wdx = sfont->Width() * 15 + 10,
                  wdh = sfont->Height() + 8;
   Widget *wd = new NumberWidget( 0, wdx, 5, w - wdx - 5, wdh,
-       't', event.GetTData(0), 0, 999, WIDGET_ALIGN_LEFT,
-       "Execute on turn", this );
+       event.GetTData(0), 0, 999, WIDGET_ALIGN_LEFT,
+       "Execute on _turn", this );
   wd->SetHook( this );
 
-  new ButtonWidget( GUI_CLOSE, 1, h - wdh - 1, w - 2, wdh, 'o',
-                    WIDGET_DEFAULT, "OK", this );
+  new ButtonWidget( GUI_CLOSE, 1, h - wdh - 1, w - 2, wdh,
+                    WIDGET_DEFAULT, "_OK", this );
   Draw();
   Show();
 }
@@ -959,7 +960,7 @@ EdTrigUnitDestroyedWindow::EdTrigUnitDestroyedWindow( Event &event,
   char buf[32] = "All";
 
   wd = new ButtonWidget( B_ID_UNIT, 5, 5,
-       sfont->Width() * 4 + 10, wdh, 'u', 0, "Unit", this );
+       sfont->Width() * 4 + 10, wdh, 0, "_Unit", this );
   wd->SetHook( this );
 
   if ( event.GetTData(0) >= 0 ) {
@@ -968,18 +969,18 @@ EdTrigUnitDestroyedWindow::EdTrigUnitDestroyedWindow( Event &event,
   }
   wdx = wd->LeftEdge() + wd->Width() + 5;
   t_unit = new StringWidget( 0, wdx, 5, w - wdx - 5, wdh,
-           0, buf, 30, WIDGET_STR_CONST, NULL, this );
+           buf, 30, WIDGET_STR_CONST, NULL, this );
 
   wdx = sfont->Width() * 20 + 10;
   t_player = new CycleWidget( B_ID_PLAYER, wdx, wd->Height() + 10,
-             w - wdx - 5, wdh, 'p',
+             w - wdx - 5, wdh,
              (event.GetTData(0) >= 0) ? WIDGET_DISABLED : 0,
-             "Controlled by Player", event.GetTData(1),
+             "Controlled by _Player", event.GetTData(1),
              player2_labels, this );
   t_player->SetHook( this );
 
-  new ButtonWidget( GUI_CLOSE, 1, h - wdh - 1, w - 2, wdh, 'o',
-                    WIDGET_DEFAULT, "OK", this );
+  new ButtonWidget( GUI_CLOSE, 1, h - wdh - 1, w - 2, wdh,
+                    WIDGET_DEFAULT, "_OK", this );
   Draw();
   Show();
 }
@@ -1046,7 +1047,7 @@ EdTrigUnitPositionWindow::EdTrigUnitPositionWindow( Event &event,
   char buf[32] = "Any";
 
   wd = new ButtonWidget( B_ID_UNIT, 5, 5,
-       sfont->Width() * 4 + 10, wdh, 'u', 0, "Unit", this );
+       sfont->Width() * 4 + 10, wdh, 0, "_Unit", this );
   wd->SetHook( this );
 
   if ( event.GetTData(0) >= 0 ) {
@@ -1055,25 +1056,25 @@ EdTrigUnitPositionWindow::EdTrigUnitPositionWindow( Event &event,
   }
   wdx = wd->LeftEdge() + wd->Width() + 5;
   t_unit = new StringWidget( 0, wdx, 5, w - wdx - 5, wdh,
-           0, buf, 30, WIDGET_STR_CONST, NULL, this );
+           buf, 30, WIDGET_STR_CONST, NULL, this );
 
   wdx = sfont->Width() * 10 + 10;
   wd = new NumberWidget( N_ID_POSX,
        wdx, wd->TopEdge() + wd->Height() + 5,
-       (w - wdx - sfont->Width() - 15) / 2, wdh, 'x',
+       (w - wdx - sfont->Width() - 15) / 2, wdh,
        event.GetTData(1), 0, mission.GetMap().Width(),
-       WIDGET_ALIGN_LEFT, "Position X", this );
+       WIDGET_ALIGN_LEFT, "Position _X", this );
   wd->SetHook( this );
 
   wdx += wd->Width() + sfont->Width() + 10;
   wd = new NumberWidget( N_ID_POSY,
-       wdx, wd->TopEdge(), w - wdx - 5, wdh, 'y',
+       wdx, wd->TopEdge(), w - wdx - 5, wdh,
        event.GetTData(2), 0, mission.GetMap().Height(),
-       WIDGET_ALIGN_LEFT, "Y", this );
+       WIDGET_ALIGN_LEFT, "_Y", this );
   wd->SetHook( this );
 
-  new ButtonWidget( GUI_CLOSE, 1, h - wdh - 1, w - 2, wdh, 'o',
-                    WIDGET_DEFAULT, "OK", this );
+  new ButtonWidget( GUI_CLOSE, 1, h - wdh - 1, w - 2, wdh,
+                    WIDGET_DEFAULT, "_OK", this );
   Draw();
   Show();
 }
@@ -1109,3 +1110,4 @@ GUI_Status EdTrigUnitPositionWindow::WidgetActivated( Widget *widget, Window *wi
 
   return GUI_OK;
 }
+
