@@ -1,5 +1,5 @@
 // CoMET - The Crimson Fields Map Editing Tool
-// Copyright (C) 2002-2003 Jens Granseuer
+// Copyright (C) 2002-2004 Jens Granseuer
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -57,12 +57,11 @@ const short EdBuildingWindow::B_ID_PLAYER = 1;
 const short EdBuildingWindow::B_ID_WORKSHOP = 2;
 const short EdBuildingWindow::B_ID_FACTORY = 3;
 const short EdBuildingWindow::B_ID_CRYSTALS = 4;
-const short EdBuildingWindow::B_ID_MINING = 5;
-const short EdBuildingWindow::B_ID_OK = 6;
-const short EdBuildingWindow::B_ID_NAME = 7;
-const short EdBuildingWindow::B_ID_UNITS = 8;
-const short EdBuildingWindow::N_ID_MAXCRYSTALS = 9;
-const short EdBuildingWindow::B_ID_FACTORY_UNITS = 10;
+const short EdBuildingWindow::B_ID_OK = 5;
+const short EdBuildingWindow::B_ID_NAME = 6;
+const short EdBuildingWindow::B_ID_UNITS = 7;
+const short EdBuildingWindow::N_ID_MAXCRYSTALS = 8;
+const short EdBuildingWindow::B_ID_FACTORY_UNITS = 9;
 
 const short EdUnitWindow::B_ID_PLAYER = 1;
 const short EdUnitWindow::B_ID_DIRECTION = 2;
@@ -143,17 +142,17 @@ ListExchangeWindow::ListExchangeWindow( TLWList &l1, TLWList &l2,
        wd_l1->LeftEdge() + wd_l1->Width() + 5,
        wd_l1->TopEdge() + wd_l1->Height()/2 - sfont->Height() - 15,
        wd_l2->LeftEdge() - wd_l1->LeftEdge() - wd_l1->Width() - 10,
-       sfont->Height() + 8, '>', 0, ">", this );
+       sfont->Height() + 8, 0, "_>", this );
   wd->SetHook( this );
 
   wd = new ButtonWidget( B_ID_LEFT, wd->LeftEdge(),
        wd->TopEdge() + wd->Height() + 7, wd->Width(), wd->Height(),
-       '<', 0, "<", this );
+       0, "_<", this );
   wd->SetHook( this );
 
   ok = new ButtonWidget( B_ID_OK, 1, h - sfont->Height() - 9,
-                         w - 2, sfont->Height() + 8, 'o',
-                         WIDGET_DEFAULT, "OK", this );
+                         w - 2, sfont->Height() + 8,
+                         WIDGET_DEFAULT, "_OK", this );
   ok->SetHook( this );
 
   Draw();
@@ -250,8 +249,8 @@ ListSelectWindow::ListSelectWindow( const char *title, TLWList &list,
   lw->SetHook( this );
 
   Widget *wd = new ButtonWidget( button, 1, h - sfont->Height() - 9,
-                   w - 2, sfont->Height() + 8, 'o', WIDGET_DEFAULT,
-                   "OK", this );
+                   w - 2, sfont->Height() + 8, WIDGET_DEFAULT,
+                   "_OK", this );
   wd->SetHook( this );
 
   Draw();
@@ -307,38 +306,40 @@ NewMissionWindow::NewMissionWindow( View *view ) : Window(WIN_CENTER, view) {
   SetSize( width, height );
 
   m_width = new NumberWidget( 1, xoff, yoff, f->Width() * 4 + 10,
-            f->Height() + 6, 'w', 40, 20, 250, WIDGET_ALIGN_LEFT,
-            "Map Width :", this );
+            f->Height() + 6, 40, 20, 250, WIDGET_ALIGN_LEFT,
+            "Map _Width :", this );
 
   width = MIN( f->Width() * 11 + 10, w - xoff - m_width->w - 24 - f->Width() * 12 );
   tileset = new StringWidget( 3, xoff + m_width->w + 10 + f->Width() * 9,
-            yoff, width, m_width->h, 't', "default", 10,
-            WIDGET_ALIGN_LEFT|WIDGET_STR_CONST, "Tile Set:", this );
+            yoff, width, m_width->h, "default", 10,
+            WIDGET_ALIGN_LEFT|WIDGET_STR_CONST, "_Tile Set:", this );
 
   ButtonWidget *btn = new ButtonWidget( B_ID_TILESET,
              tileset->x + tileset->w, tileset->y,
-             f->Width() * 3 + 4, tileset->h, 't', 0, "...", this );
+             f->Width() * 3 + 4, tileset->h, 0, "...", this );
+  btn->SetKey( 't' );
   btn->SetHook( this );
 
   yoff += m_width->Height() + 5;
 
   m_height = new NumberWidget( 2, xoff, yoff, m_width->w, m_width->h,
-            'h', 40, 20, 250, WIDGET_ALIGN_LEFT, "Map Height:", this );
+            40, 20, 250, WIDGET_ALIGN_LEFT, "Map _Height:", this );
 
   unitset = new StringWidget( 4, tileset->x, yoff, tileset->w, tileset->h,
-            'u', "default", 10, WIDGET_ALIGN_LEFT|WIDGET_STR_CONST,
-            "Unit Set:", this );
+            "default", 10, WIDGET_ALIGN_LEFT|WIDGET_STR_CONST,
+            "_Unit Set:", this );
 
   btn = new ButtonWidget( B_ID_UNITSET,
-             btn->x, unitset->y, btn->w, unitset->h, 'u', 0, "...", this );
+             btn->x, unitset->y, btn->w, unitset->h, 0, "...", this );
+  btn->SetKey( 'u' );
   btn->SetHook( this );
 
   yoff = h - f->Height() - 15;
   ok = new ButtonWidget( B_ID_NMW_CREATE, 10, yoff, f->Width() * 10,
-       f->Height() + 10, 'o', 0, "OK", this );
+       f->Height() + 10, 0, "_OK", this );
 
   new ButtonWidget( GUI_CLOSE, w - 10 - ok->w, yoff, ok->w, ok->h,
-                    'c', 0, "Cancel", this );
+                    0, "_Cancel", this );
   Draw();
   Show();
 }
@@ -425,44 +426,44 @@ EdMissionSetupWindow::EdMissionSetupWindow( Mission &mission, View *view ) :
 
   wdx = sfont->Width() * 8 + 10;
   wd = new StringWidget( S_ID_PLAYER1,
-       wdx, wdy, w/2 - wdx - 5, wdh, '1',
-       p1.Name(), 15, WIDGET_ALIGN_LEFT, "Player 1", this );
+       wdx, wdy, w/2 - wdx - 5, wdh,
+       p1.Name(), 15, WIDGET_ALIGN_LEFT, "Player _1", this );
   wd->SetHook( this );
 
   wd = new StringWidget( S_ID_PLAYER2,
-       wdx * 2 + wd->Width(), wdy, wd->Width(), wdh, '2',
-       p2.Name(), 15, WIDGET_ALIGN_LEFT, "Player 2", this );
+       wdx * 2 + wd->Width(), wdy, wd->Width(), wdh,
+       p2.Name(), 15, WIDGET_ALIGN_LEFT, "Player _2", this );
   wd->SetHook( this );
            
   wdy += wdh + 5;
   wd = new ButtonWidget( B_ID_BRIEFING1, 5, wdy,
-       w/2 - 10, wdh, 'b', 0, "Briefing Player 1", this );
+       w/2 - 10, wdh, 0, "_Briefing Player 1", this );
   wd->SetHook( this );
 
   wd = new ButtonWidget( B_ID_BRIEFING2, w/2 + 5, wdy,
-       wd->Width(), wdh, 'r', 0, "Briefing Player 2", this );
+       wd->Width(), wdh, 0, "B_riefing Player 2", this );
   wd->SetHook( this );
 
   wdx = sfont->Width() * 4 + 10;
   wdy += wd->Height() + 5;
   showmsg = new CycleWidget( B_ID_PLAYERS, wdx, wdy,
-            w/2 - wdx - 5, wdh, 't', WIDGET_ALIGN_LEFT,
-            "Type", mission.GetNumPlayers()-1, type_labels, this );
+            w/2 - wdx - 5, wdh, WIDGET_ALIGN_LEFT,
+            "_Type", mission.GetNumPlayers()-1, type_labels, this );
   showmsg->SetHook( this );
 
   wdx = w/2 + sfont->Width() * 8 + 10;
   wd = new StringWidget( S_ID_PASSWORD, wdx, wdy, w - wdx - 5, wdh,
-       'p', mission.GetPassword(), 7, WIDGET_ALIGN_LEFT,
-       "Password", this );
+       mission.GetPassword(), 7, WIDGET_ALIGN_LEFT,
+       "_Password", this );
   wd->SetHook( this );
 
   wdy += wd->Height() + 5;
   wd = new ButtonWidget( B_ID_INFOMSG, 5, wdy, w/2 - 10, wdh,
-       'i', 0, "Level Info", this );
+       0, "Level _Info", this );
   wd->SetHook( this );
 
   wd = new ButtonWidget( B_ID_NEXTMAP, w/2 + 5, wdy,
-       wd->Width(), wdh, 's', 0, "Sequel", this );
+       wd->Width(), wdh, 0, "_Sequel", this );
   wd->SetHook( this );
 
   // the user can use the following widget to choose which message to
@@ -471,7 +472,7 @@ EdMissionSetupWindow::EdMissionSetupWindow( Mission &mission, View *view ) :
   wdx = sfont->Width() * 12 + 10;
   wdy += wd->Height() + 10;
   showmsg = new CycleWidget( B_ID_SHOWMSG, wdx, wdy, w - wdx - 5, wdh,
-            'm', WIDGET_ALIGN_LEFT, "Show Message", 0, msg_labels,
+            WIDGET_ALIGN_LEFT, "Show _Message", 0, msg_labels,
             this );
   showmsg->SetHook( this );
 
@@ -483,7 +484,7 @@ EdMissionSetupWindow::EdMissionSetupWindow( Mission &mission, View *view ) :
         0, NULL, this );
 
   new ButtonWidget( GUI_CLOSE, 1, h - wdh - 1, w - 2, wdh,
-                    'o', WIDGET_DEFAULT, "OK", this );
+                    WIDGET_DEFAULT, "_OK", this );
 
   Draw();
   Show();
@@ -596,51 +597,57 @@ EdBuildingWindow::EdBuildingWindow( Building &bld, Mission &mission, View *view
   unsigned short xoff, yoff = 5, wdh = sfont->Height() + 10;
 
   b_name = new StringWidget( B_ID_NAME, 5, yoff, w/2 - 10, wdh,
-                             'n', b.Name(), 19, 0, NULL, this );
+                             b.Name(), 19, 0, NULL, this );
 
   xoff = w/2 + 10 + sfont->TextWidth("Player");
   b_player = new CycleWidget( B_ID_PLAYER, xoff, yoff, w - 5 - xoff, wdh,
-                              'p', 0, "Player", b.Owner(), player3_labels, this );
+                              0, "_Player", b.Owner(), player3_labels, this );
   yoff += 5 + wdh;
 
   ButtonWidget *btn;
   btn = new CheckboxWidget( B_ID_WORKSHOP, 5, yoff, DEFAULT_CBW_SIZE,
-                            DEFAULT_CBW_SIZE, b.IsWorkshop(), 'w',
+                            DEFAULT_CBW_SIZE, b.IsWorkshop(),
                             WIDGET_STYLE_NOBORDER|WIDGET_STYLE_GFX|WIDGET_ALIGN_RIGHT,
-                            "Workshop", this );
+                            "_Workshop", this );
   btn->SetHook( this );
 
   btn = new CheckboxWidget( B_ID_FACTORY, 5, yoff + DEFAULT_CBW_SIZE + 5,
-                            DEFAULT_CBW_SIZE, DEFAULT_CBW_SIZE, b.IsFactory(), 'f',
+                            DEFAULT_CBW_SIZE, DEFAULT_CBW_SIZE, b.IsFactory(),
                             WIDGET_STYLE_NOBORDER|WIDGET_STYLE_GFX|WIDGET_ALIGN_RIGHT,
-                            "Factory", this );
+                            "_Factory", this );
   btn->SetHook( this );
 
   btn = new ButtonWidget( B_ID_UNITS, w/2 + 5, yoff, (w - 20)/2, wdh,
-                          'u', 0, "Units...", this ),
+                          0, "_Units...", this ),
   btn->SetHook( this );
   yoff += 5 + wdh;
 
   b_factory_units = new ButtonWidget( B_ID_FACTORY_UNITS, btn->LeftEdge(), yoff,
-                    btn->Width(), wdh, 'a', (b.IsFactory() ? 0 : WIDGET_DISABLED),
-                    "Factory Settings...", this );
+                    btn->Width(), wdh, (b.IsFactory() ? 0 : WIDGET_DISABLED),
+                    "F_actory Settings...", this );
   b_factory_units->SetHook( this );
   yoff += 5 + wdh;
 
   xoff = 10 + sfont->TextWidth("Crystals");
   b_crystals = new NumberWidget( 0, xoff, yoff, sfont->Width() * 4 + 10, wdh,
-                                 'c', b.Crystals(), 0, b.CrystalStore(),
-                                 WIDGET_ALIGN_LEFT, "Crystals", this );
+                                 b.Crystals(), 0, b.CrystalStore(),
+                                 WIDGET_ALIGN_LEFT, "_Crystals", this );
 
   xoff += b_crystals->Width() + 10 + sfont->TextWidth("of");
   b_maxcrystals = new NumberWidget( N_ID_MAXCRYSTALS, xoff, yoff,
-                                  b_crystals->Width(), wdh, 0,
-                                  b.CrystalStore(), 0, 1000,
+                                  b_crystals->Width(), wdh,
+                                  b.CrystalStore(), 0, 10000,
                                   WIDGET_ALIGN_LEFT, "of", this );
   b_maxcrystals->SetHook( this );
 
-  btn = new ButtonWidget( B_ID_OK, 1, h - 1 - wdh, w - 2, wdh, 'o',
-                          WIDGET_DEFAULT, "OK", this ),
+  xoff = w/2 + 5 + sfont->Width() * 7;
+  b_mining = new NumberWidget( 0, xoff, yoff,
+                               b_crystals->Width(), wdh,
+                               b.CrystalProduction(), 0, 1000,
+                               WIDGET_ALIGN_LEFT, "O_utput", this );
+
+  btn = new ButtonWidget( B_ID_OK, 1, h - 1 - wdh, w - 2, wdh,
+                          WIDGET_DEFAULT, "_OK", this ),
   btn->SetHook( this );
 
   Draw();
@@ -700,6 +707,7 @@ GUI_Status EdBuildingWindow::WidgetActivated( Widget *widget, Window *win ) {
     b.SetName( b_name->String() );
     b.SetCrystals( b_crystals->Number() );
     b.SetMaxCrystals( b_maxcrystals->Number() );
+    b.SetCrystalProduction( b_mining->Number() );
 
     for ( Unit *u = static_cast<Unit *>(mission.GetUnits().Head()); u;
           u = static_cast<Unit *>(u->Next()) ) {
@@ -744,26 +752,26 @@ EdUnitWindow::EdUnitWindow( Unit &unit, Mission &mission, View *view ) :
   unsigned short xoff, yoff = 5, wdh = sfont->Height() + 10;
 
   Widget *wd = new StringWidget( 0, 5, yoff, w/2 - 10, wdh,
-                   0, u.Name(), 19,
+                   u.Name(), 19,
                    WIDGET_STYLE_NOBORDER|WIDGET_STR_CONST,
                    NULL, this );
   xoff = w/2 + 10 + sfont->TextWidth("Player");
   u_player = new CycleWidget( B_ID_PLAYER, xoff, yoff, w - 5 - xoff, wdh,
-                              'p', (u.IsSheltered() ? WIDGET_DISABLED : 0),
-                              "Player", u.Owner(),
+                              (u.IsSheltered() ? WIDGET_DISABLED : 0),
+                              "_Player", u.Owner(),
                               (u.IsSheltered() ? player3_labels : player2_labels),
                               this );
   u_player->SetHook( this );
   yoff += 5 + wdh;
 
   new NumberWidget( 0, wd->LeftEdge() + 10 + sfont->Width() * 2,
-                    yoff, sfont->Width() * 6, wdh, 0, u.ID(), 0, 32000,
+                    yoff, sfont->Width() * 6, wdh, u.ID(), 0, 32000,
                     WIDGET_ALIGN_LEFT|WIDGET_STYLE_NOBORDER|WIDGET_STR_CONST,
                     "ID", this );
 
   xoff = w/2 + 10 + sfont->TextWidth("Direction");
   wd = new CycleWidget( B_ID_DIRECTION, xoff, yoff, w - 5 - xoff, wdh,
-                        'd', 0, "Direction", u.GetDirection(), dir_labels, this );
+                        0, "_Direction", u.GetDirection(), dir_labels, this );
   wd->SetHook( this );
   yoff += 5 + wdh;
 
@@ -775,19 +783,19 @@ EdUnitWindow::EdUnitWindow( Unit &unit, Mission &mission, View *view ) :
     // changes, so we allow the maximum here and update manually when the
     // widget is activated if necessary
     wd = new NumberWidget( N_ID_CRYSTALS, xoff, yoff, sfont->Width() * 6, wdh,
-                           0, u.Crystals(), 0, u.Type()->Slots() * 10,
+                           u.Crystals(), 0, u.Type()->Slots() * 10,
                            WIDGET_ALIGN_LEFT, "Crystals", this );
     wd->SetHook( this );
 
     if ( !u.IsSheltered() ) {
       wd = new ButtonWidget( B_ID_UNITS, w/2 + 5, yoff, (w - 20)/2, wdh,
-                             'u', 0, "Units...", this ),
+                             0, "_Units...", this ),
       wd->SetHook( this );
     }
   }
 
   wd = new ButtonWidget( B_ID_OK, 1, h - 1 - wdh, w - 2, wdh,
-                         'o', WIDGET_DEFAULT, "OK", this ),
+                         WIDGET_DEFAULT, "_OK", this ),
   wd->SetHook( this );
 
   Draw();
@@ -860,22 +868,22 @@ EdEventsWindow::EdEventsWindow( Mission &mission, View *view ) :
 
   ButtonWidget *btn = new ButtonWidget( B_ID_NEW,
                1, h - sfont->Height() * 2 - 17, (w - 2)/2, sfont->Height() + 8,
-               'n', 0, "New", this );
+               0, "_New", this );
   btn->SetHook( this );
 
   btn = new ButtonWidget( B_ID_EDIT,
               btn->LeftEdge() + btn->Width(), btn->TopEdge(),
-              btn->Width(), btn->Height(), 'e', 0, "Edit", this );
+              btn->Width(), btn->Height(), 0, "_Edit", this );
   btn->SetHook( this );
 
   btn = new ButtonWidget( B_ID_DELETE,
               btn->LeftEdge() - btn->Width(), btn->TopEdge() + btn->Height(),
-              btn->Width(), btn->Height(), 'd', 0, "Delete", this );
+              btn->Width(), btn->Height(), 0, "_Delete", this );
   btn->SetHook( this );
 
   btn = new ButtonWidget( B_ID_OK,
               btn->LeftEdge() + btn->Width(), btn->TopEdge(),
-              btn->Width(), btn->Height(), 'o', 0, "OK", this );
+              btn->Width(), btn->Height(), 0, "_OK", this );
   btn->SetHook( this );
 
   Draw();
@@ -949,17 +957,17 @@ SelectEventWindow::SelectEventWindow( Mission &mission, View *view ) :
 
   e_trigger = new CycleWidget( B_ID_TRIGGER, e_list->LeftEdge(),
                   e_list->TopEdge() + e_list->Height() + sfont->Height() + 10,
-                  e_list->Width(), sfont->Height() + 8, 't', WIDGET_ALIGN_TOP,
-                  "Triggered by", 0, etrigger_labels, this );
+                  e_list->Width(), sfont->Height() + 8, WIDGET_ALIGN_TOP,
+                  "_Triggered by", 0, etrigger_labels, this );
 
   ButtonWidget *btn = new ButtonWidget( B_ID_OK,
                1, h - sfont->Height() - 9, (w - 2)/2, sfont->Height() + 8,
-               'o', WIDGET_DEFAULT, "OK", this );
+               WIDGET_DEFAULT, "_OK", this );
   btn->SetHook( this );
 
   btn = new ButtonWidget( B_ID_CANCEL,
               btn->LeftEdge() + btn->Width(), btn->TopEdge(),
-              btn->Width(), btn->Height(), 'c', 0, "Cancel", this );
+              btn->Width(), btn->Height(), 0, "_Cancel", this );
   btn->SetHook( this );
 
   Draw();
@@ -1034,22 +1042,22 @@ EdUnitsWindow::EdUnitsWindow( Mission &mission, MapObject &container, View *view
 
   ButtonWidget *btn = new ButtonWidget( B_ID_NEW,
                1, h - sfont->Height() * 2 - 17, (w - 2)/2, sfont->Height() + 8,
-               'n', 0, "New", this );
+               0, "_New", this );
   btn->SetHook( this );
 
   btn = new ButtonWidget( B_ID_EDIT,
               btn->LeftEdge() + btn->Width(), btn->TopEdge(),
-              btn->Width(), btn->Height(), 'e', 0, "Edit", this );
+              btn->Width(), btn->Height(), 0, "_Edit", this );
   btn->SetHook( this );
 
   btn = new ButtonWidget( B_ID_DELETE,
               btn->LeftEdge() - btn->Width(), btn->TopEdge() + btn->Height(),
-              btn->Width(), btn->Height(), 'd', 0, "Delete", this );
+              btn->Width(), btn->Height(), 0, "_Delete", this );
   btn->SetHook( this );
 
   btn = new ButtonWidget( B_ID_OK,
               btn->LeftEdge() + btn->Width(), btn->TopEdge(),
-              btn->Width(), btn->Height(), 'o', 0, "OK", this );
+              btn->Width(), btn->Height(), 0, "_OK", this );
   btn->SetHook( this );
 
   Draw();
@@ -1201,12 +1209,12 @@ void SelectUnitWindow::Init( TLWList &list, WidgetHook *hook ) {
 
   ButtonWidget *btn = new ButtonWidget( B_ID_SUW_OK,
                1, h - sfont->Height() - 9, (w - 2)/2, sfont->Height() + 8,
-               'o', WIDGET_DEFAULT, "OK", this );
+               WIDGET_DEFAULT, "_OK", this );
   btn->SetHook( hook );
 
   btn = new ButtonWidget( B_ID_CANCEL,
               btn->LeftEdge() + btn->Width(), btn->TopEdge(),
-              btn->Width(), btn->Height(), 'c', 0, "Cancel", this );
+              btn->Width(), btn->Height(), 0, "_Cancel", this );
   btn->SetHook( this );
 
   Draw();
