@@ -1,5 +1,5 @@
 // CoMET - The Crimson Fields Map Editing Tool
-// Copyright (C) 2002-2003 Jens Granseuer
+// Copyright (C) 2002-2004 Jens Granseuer
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -40,7 +40,7 @@
 GfxWidget::GfxWidget( short id, short x, short y, unsigned short w,
     unsigned short h, unsigned short flags, const char *title,
     Window *window ) :
-    Widget( id, x, y, w, h, 0, flags, title, window ),
+    Widget( id, x, y, w, h, flags, title, window ),
     bounds( x + 4, y + 4, w - 8 - DEFAULT_SLIDER_SIZE, h - 8 ) {
   slider = NULL;
 
@@ -75,7 +75,7 @@ void GfxWidget::Init( unsigned short gfxw, unsigned short gfxh, unsigned short i
   } else { 
     // create the corresponding slider widget
     slider = new SliderWidget( id + 1, x + w - DEFAULT_SLIDER_SIZE, y,
-       DEFAULT_SLIDER_SIZE, h, 0, rows - visrows, toprow, visrows, 0,
+       DEFAULT_SLIDER_SIZE, h, 0, rows - visrows, toprow, visrows,
        WIDGET_VSCROLL, NULL, surface );
     slider->SetHook( this );
     SetSize( x, y, w - DEFAULT_SLIDER_SIZE, h );   // adjust widget size
