@@ -1,5 +1,5 @@
 // CoMET - The Crimson Fields Map Editing Tool
-// Copyright (C) 2002-2003 Jens Granseuer
+// Copyright (C) 2002-2004 Jens Granseuer
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -26,12 +26,12 @@
 #include "fileio.h"
 #include "globals.h"
 
-const char *event_labels[] = { "Message", "Mining", "Score", "Next Map",
-                               "Create Unit", "Manipulate Event",
-                               "Research", 0 };
-const char *etrigger_labels[] = { "Turn", "Unit Destruction",
-                                  "Shop Owner", "Unit Owner",
-                                  "Unit Position", 0 };
+const char *event_labels[] = {
+      "Message", "Mining", "Score", "Next Map",
+      "Create Unit", "Manipulate Event", "Research", 0 };
+const char *etrigger_labels[] = {
+      "Turn", "Unit Destruction", "Shop Owner", "Unit Owner",
+      "Unit Position", 0 };
 
 ////////////////////////////////////////////////////////////////////////
 // NAME       : Mission::Mission
@@ -243,6 +243,12 @@ int Mission::Save( const char *filename ) {
   SDL_WriteLE16( file, flags );
   SDL_WriteLE16( file, 1 );        // turn
 
+  if ( flags & GI_PASSWORD ) {
+    crypt( password );
+    SDL_RWwrite( file, password, 1, 8 );
+    crypt( password );
+  }
+
   SDL_RWwrite( file, &level_info, 1, 1 );
   SDL_RWwrite( file, &next_map, 1, 1 );
   SDL_RWwrite( file, &current_player, 1, 1 );
@@ -630,7 +636,10 @@ void Mission::SetPassword( const char *pass ) {
 
   for ( int i = 0; i < 8; ++i ) password[i] = '\0';
 
-  if ( pass ) strncpy( password, pass, 7 );
+  if ( pass ) {
+    strncpy( password, pass, 7 );
+    flags |= GI_PASSWORD;
+  } else flags &= ~GI_PASSWORD;
 }
 
 ////////////////////////////////////////////////////////////////////////
@@ -919,8 +928,8 @@ int Player::Load( SDL_RWops *file ) {
   SDL_RWread( file, &p_level, 1, 1 );
   SDL_RWread( file, &p_success, 1, 1 );
   SDL_RWread( file, &p_briefing, 1, 1 );
-  SDL_RWread( file, &p_name, 1, 16 );
-  SDL_RWread( file, &p_password, 1, 8 );
+  SDL_RWread( file, p_name, 1, 16 );
+  SDL_RWread( file, p_password, 1, 8 );
   return 0;
 }
 
@@ -936,8 +945,8 @@ int Player::Save( SDL_RWops *file ) const {
   SDL_RWwrite( file, &p_level, 1, 1 );
   SDL_RWwrite( file, &p_success, 1, 1 );
   SDL_RWwrite( file, &p_briefing, 1, 1 );
-  SDL_RWwrite( file, &p_name, 1, 16 );
-  SDL_RWwrite( file, &p_password, 1, 8 );
+  SDL_RWwrite( file, p_name, 1, 16 );
+  SDL_RWwrite( file, p_password, 1, 8 );
   return 0;
 }
 
@@ -1088,8 +1097,8 @@ int Event::Save( SDL_RWops *file ) const {
 ////////////////////////////////////////////////////////////////////////
 
 int Event::Export( ofstream &file, const UnitSet *uset ) const {
-  const char *type[] = { "message", "mining", "score", "nextmap",
-                         "createunit", "manipulateevent", "research" };
+  const char *type[] = { "message", "mining", "score",
+        "nextmap", "createunit", "manipulateevent", "research" };
 
   file << "[event]\n";
   file << "id = " << (short)e_id << '\n';
