@@ -1,5 +1,5 @@
 // Crimson Fields -- a game of tactical warfare
-// Copyright (C) 2000-2003 Jens Granseuer
+// Copyright (C) 2000-2004 Jens Granseuer
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -32,7 +32,6 @@
 //              y      - top edge of widget
 //              w      - widget width
 //              h      - widget height
-//              key    - key equivalent for mouse clicks
 //              flags  - see widget.h for details
 //              title  - widget title (may be NULL)
 //              window - widget parent window
@@ -40,9 +39,9 @@
 ////////////////////////////////////////////////////////////////////////
 
 ButtonWidget::ButtonWidget( short id, short x, short y, unsigned short w,
-                       unsigned short h, short key, unsigned short flags,
+                       unsigned short h, unsigned short flags,
                        const char *title, Window *window ) :
-     Widget( id, x, y, w, h, key, flags, title, window ) {}
+     Widget( id, x, y, w, h, flags, title, window ) {}
 
 ////////////////////////////////////////////////////////////////////////
 // NAME       : ButtonWidget::Draw
@@ -198,7 +197,6 @@ GUI_Status ButtonWidget::Activate( void ) {
 //              w      - widget width
 //              h      - widget height
 //              state  - initial state (checked or unchecked)
-//              key    - key equivalent for mouse clicks
 //              flags  - see widget.h for details
 //              title  - widget title (may be NULL)
 //              window - widget parent window
@@ -212,9 +210,9 @@ GUI_Status ButtonWidget::Activate( void ) {
 #define GFX_CHECK_ON_Y    46
 
 CheckboxWidget::CheckboxWidget( short id, short x, short y, unsigned short w,
-                       unsigned short h, bool state, short key,
-                       unsigned short flags, const char *title, Window *window ) :
-     ButtonWidget( id, x, y, w, h, key, flags, title, window ) {
+                       unsigned short h, bool state, unsigned short flags,
+                       const char *title, Window *window ) :
+     ButtonWidget( id, x, y, w, h, flags, title, window ) {
   clicked = state;
 
   // set default graphics
@@ -278,7 +276,6 @@ GUI_Status CheckboxWidget::KeyDown( const SDL_keysym &key ) {
 //              y      - top edge of widget
 //              w      - widget width
 //              h      - widget height
-//              key    - key equivalent for mouse clicks
 //              flags  - see widget.h for details
 //              title  - widget title (may be NULL)
 //              window - widget parent window
@@ -286,9 +283,9 @@ GUI_Status CheckboxWidget::KeyDown( const SDL_keysym &key ) {
 ////////////////////////////////////////////////////////////////////////
 
 MenuButtonWidget::MenuButtonWidget( short id, short x, short y, unsigned short w,
-                  unsigned short h, short key, unsigned short flags,
+                  unsigned short h, unsigned short flags,
                   const char *title, Window *window ) :
-      ButtonWidget( id, x, y, w, h, key, flags, title, window ) {
+      ButtonWidget( id, x, y, w, h, flags, title, window ) {
   image[0] = Image( window->GetView()->GetSystemIcons(), 175, 46, 7, 11 );
 }
 
