@@ -1,5 +1,5 @@
 // Crimson Fields -- a game of tactical warfare
-// Copyright (C) 2000-2003 Jens Granseuer
+// Copyright (C) 2000-2004 Jens Granseuer
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -33,10 +33,9 @@
 // PARAMETERS : title   - window title (may be NULL)
 //              msg     - message
 //              buttons - captions of the button widgets, separated by
-//                        '|'. The first character of each caption will
-//                        be used as the keyboard shortcut for that
-//                        button. The buttons will be assigned ID's of
-//                        GUI_CLOSE by default.
+//                        '|'. The first underscore in each caption (if
+//                        any) will be used as the keyboard shortcut for
+//                        that button.
 //              def     - identifier of the default button (starting from
 //                        0; -1 for none)
 //              flags   - window flags (see window.h for details)
@@ -100,9 +99,9 @@ DialogWindow::DialogWindow( const char *title, const string &msg,
   char *cap = bcaptions;
   for ( int i = 0; i < btncnt; ++i ) {
     btns[i] = new ButtonWidget( GUI_CLOSE, bx, by,
-                  btnw, sfont->Height() + 6, cap[0],
+                  btnw, sfont->Height() + 6,
                   (def == i) ? WIDGET_DEFAULT : 0,
-                  &cap[1], this );
+                  cap, this );
 
     bx += btnw + bspacing;
     do { ++cap; } while ( *cap != '\0' );
@@ -174,7 +173,7 @@ MessageWindow::MessageWindow( const char *title, const char *msg, View *view ) :
   SetSize( MAX(view->Width()/2, 320), MAX(view->Height()*3/4, 240) );
 
   button = new ButtonWidget( GUI_CLOSE, 1, h - sfont->Height() - 11, w - 2, sfont->Height() + 10,
-                             'o', WIDGET_DEFAULT, "OK", this );
+                             WIDGET_DEFAULT, "_OK", this );
 
   short boxy = 5;
   if ( title ) boxy += lfont->Height() * 2;
@@ -233,13 +232,13 @@ PasswordWindow::PasswordWindow( const char *title, const char *msg,
 
   string = new StringWidget( 0, (w - sfont->Width() * 9 - 4) / 2,
                              h - sfont->Height() * 2 - 30,
-                             sfont->Width() * 9 + 4, sfont->Height() + 4, 'p',
+                             sfont->Width() * 9 + 4, sfont->Height() + 4,
                              NULL, 7, WIDGET_ALIGN_TOP|WIDGET_STR_PASSWORD,
                              msg, this );
 
   button = new ButtonWidget( GUI_CLOSE, 1, h - sfont->Height() - 9,
-                             w - 2, sfont->Height() + 8, 'o', WIDGET_DEFAULT,
-                             "OK", this );
+                             w - 2, sfont->Height() + 8, WIDGET_DEFAULT,
+                             "_OK", this );
   Draw();
   Show();
   string->SetFocus();
@@ -317,7 +316,7 @@ ProgressWindow::ProgressWindow( short x, short y, unsigned short w,
   if ( flags & WIN_PROG_ABORT ) {
     bwidth = sfont->Width() * 5 + 20;
     new ButtonWidget( GUI_CLOSE, w - bwidth - 5, 5, bwidth, h - 10,
-                      'a', WIDGET_DEFAULT, "Abort", this );
+                      WIDGET_DEFAULT, "_Abort", this );
   }
 
   progress = new ProgressWidget( GUI_OK, 5, 5, w - 10 - bwidth, h - 10,
@@ -369,7 +368,7 @@ MenuWindow::MenuWindow( const char *title, WidgetHook *hook, View *view ) :
   barheight = vspacing * 2 + 2;		// height of the separator bar
 
   if ( title ) {
-    items.AddHead( new MenuItem( MENU_TITLE, 0, 0, 0, 0, title ) );
+    items.AddHead( new MenuItem( MENU_TITLE, 0, 0, 0, title ) );
     AddBar( 0 );
   }
 }
@@ -381,14 +380,13 @@ MenuWindow::MenuWindow( const char *title, WidgetHook *hook, View *view ) :
 //              id    - menu button identifier for this item
 //              flags - button flags (see widget.h for details)
 //              title - menu item caption
-//              key   - keyboard activation key
 // RETURNS    : -
 ////////////////////////////////////////////////////////////////////////
 
 void MenuWindow::AddItem( unsigned char level, short id, unsigned short flags,
-                          const char *title, unsigned short key ) {
+                          const char *title ) {
   items.AddTail(
-    new MenuItem( MENU_ITEM, level, id, flags, key, title )
+    new MenuItem( MENU_ITEM, level, id, flags, title )
   );
 }
 
@@ -398,18 +396,17 @@ void MenuWindow::AddItem( unsigned char level, short id, unsigned short flags,
 // PARAMETERS : level - menu level the menu will be added to (root is 0)
 //              flags - button flags (see widget.h for details)
 //              title - sub-menu caption
-//              key   - keyboard activation key
 // RETURNS    : -
 ////////////////////////////////////////////////////////////////////////
 
 void MenuWindow::AddMenu( unsigned char level, unsigned short flags,
-                          const char *title, unsigned short key ) {
+                          const char *title ) {
   items.AddTail(
-    // sub-menues get their position in the items list as identifier;
+    // sub-menus get their position in the items list as identifier;
     // that way the internal button handler can easily get the data
     // from the list
     new MenuItem( MENU_SUBMENU, level, items.CountNodes(),
-                  flags|WIDGET_STYLE_SUBMENU, key, title )
+                  flags|WIDGET_STYLE_SUBMENU, title )
   );
 }
 
@@ -422,7 +419,7 @@ void MenuWindow::AddMenu( unsigned char level, unsigned short flags,
 
 void MenuWindow::AddBar( unsigned char level ) {
   items.AddTail(
-    new MenuItem( MENU_SEPARATOR, level, 0, 0, 0, "" )
+    new MenuItem( MENU_SEPARATOR, level, 0, 0, "" )
   );
 }
 
@@ -496,7 +493,7 @@ void MenuWindow::Layout( void ) {
       if ( (mi->mi_type == MENU_ITEM) || (mi->mi_type == MENU_SUBMENU) ) {
 
         MenuButtonWidget *mbw = new MenuButtonWidget( mi->mi_id, 5, ypos,
-            w-10, sfont->Height() + vspacing, mi->mi_key,
+            w-10, sfont->Height() + vspacing,
             WIDGET_STYLE_MENU|WIDGET_STYLE_NOBORDER|mi->mi_flags,
             mi->mi_title.c_str(), this );
         mbw->SetHook( (mi->mi_type == MENU_ITEM ? item_hook : this) );
@@ -508,7 +505,6 @@ void MenuWindow::Layout( void ) {
     mi = static_cast<MenuItem *>( mi->Next() );
   } while ( mi && (mi->mi_level >= lev) );
 
-
   layout = true;
   if ( lev == 0 ) Audio::PlaySfx( Audio::SND_GUI_MENU_SHOW, 0 );
   Draw();
@@ -634,11 +630,11 @@ GUI_Status MenuWindow::WidgetActivated( Widget *button, Window *win ) {
     switch ( mi->mi_type ) {
     case MENU_ITEM:
       sub->AddItem( mi->mi_level, mi->mi_id, mi->mi_flags,
-                    mi->mi_title.c_str(), mi->mi_key );
+                    mi->mi_title.c_str() );
       break;
     case MENU_SUBMENU:
       sub->AddMenu( mi->mi_level, mi->mi_flags,
-                    mi->mi_title.c_str(), mi->mi_key );
+                    mi->mi_title.c_str() );
       break;
    case MENU_SEPARATOR:
       sub->AddBar( mi->mi_level );
@@ -786,14 +782,12 @@ MenuButtonWidget *MenuWindow::CurrentItem( void ) const {
 //              lev   - menu level this item belongs to
 //              id    - identifier for this item
 //              flags - button flags (see widget.h for details)
-//              key   - keyboard shortcut for this item
 //              title - item caption
 // RETURNS    : -
 ////////////////////////////////////////////////////////////////////////
 
 MenuWindow::MenuItem::MenuItem( unsigned char type, unsigned char lev, short id,
-                    unsigned short flags, unsigned short key,
-                    const string &title ) :
+                    unsigned short flags, const string &title ) :
           mi_type(type), mi_level(lev), mi_id(id), mi_flags(flags),
-          mi_key(key), mi_title(title) {}
+          mi_title(title) {}
 
