@@ -1,5 +1,5 @@
 // Crimson Fields -- a game of tactical warfare
-// Copyright (C) 2000-2003 Jens Granseuer
+// Copyright (C) 2000-2004 Jens Granseuer
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -43,7 +43,7 @@
 TextWidget::TextWidget( short id, short x, short y,
            unsigned short w, unsigned short h, const char *str,
            unsigned short flags, const char *title, Window *window ) :
-    Widget( id, x, y, w, h, 0, flags, title, window ) {
+    Widget( id, x, y, w, h, flags, title, window ) {
   text = NULL;
   lineptr = NULL;
   spacing = 2;
@@ -235,7 +235,7 @@ TextScrollWidget::TextScrollWidget( short id, short x, short y,
   current = 0;
   slider = new SliderWidget( id + 1, x + w - DEFAULT_SLIDER_SIZE, y,
                DEFAULT_SLIDER_SIZE, h, 0, Rows() - RowsVisible(), 0, RowsVisible(),
-               0, WIDGET_VSCROLL|WIDGET_HSCROLLKEY|WIDGET_VSCROLLKEY,
+               WIDGET_VSCROLL|WIDGET_HSCROLLKEY|WIDGET_VSCROLLKEY,
                NULL, window );
   slider->SetKeyStep( font->Height() + 2 );
   slider->SetHook( this );
@@ -336,7 +336,6 @@ void TextListWidget::PrintItem( const TLWNode *item, Surface *dest,
 //              y      - top edge of widget
 //              w      - widget width
 //              h      - widget height
-//              key    - keystroke to activate widget
 //              str    - string to display
 //              maxlen - maximum length of string in characters (not
 //                       including the trailing NUL-byte)
@@ -347,10 +346,10 @@ void TextListWidget::PrintItem( const TLWNode *item, Surface *dest,
 ////////////////////////////////////////////////////////////////////////
 
 StringWidget::StringWidget( short id, short x, short y, unsigned short w,
-              unsigned short h, short key, const char *str,
+              unsigned short h, const char *str,
               unsigned short maxlen, unsigned short flags,
               const char *title, Window *window ) :
-      Widget( id, x, y, w, h, key, flags, title, window ),
+      Widget( id, x, y, w, h, flags, title, window ),
       cursor(0), maxlen(maxlen), cursorpix(0), offset(0),
       strbox(x+4,y+(h-font->Height())/2,w-8,font->Height()),
       validator(0) {
