@@ -1,5 +1,5 @@
 // Crimson Fields -- a game of tactical warfare
-// Copyright (C) 2000-2003 Jens Granseuer
+// Copyright (C) 2000-2004 Jens Granseuer
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -132,8 +132,8 @@ public:
 class StringWidget : public Widget {
 public:
   StringWidget( short id, short x, short y, unsigned short w, unsigned short h,
-                short key, const char *str, unsigned short maxlen,
-                unsigned short flags, const char *title, Window *window );
+                const char *str, unsigned short maxlen, unsigned short flags,
+                const char *title, Window *window );
   ~StringWidget( void );
   virtual void Draw( void );
 
