@@ -1,5 +1,5 @@
 // Crimson Fields -- a game of tactical warfare
-// Copyright (C) 2000-2003 Jens Granseuer
+// Copyright (C) 2000-2004 Jens Granseuer
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -37,24 +37,24 @@
 //              y      - top edge of widget
 //              w      - widget width
 //              h      - widget height
-//              key    - keystroke to activate widget
 //              flags  - widget flags (see widget.h for details)
-//              title  - widget title, may be NULL
+//              title  - widget title, may be NULL, underscore chooses
+//                       keystroke
 //              window - window to attach widget to
 // RETURNS    : -
 ////////////////////////////////////////////////////////////////////////
 
 Widget::Widget( short id, short x, short y, unsigned short w, unsigned short h,
-        short key, unsigned short flags, const char *title, Window *window ) :
+        unsigned short flags, const char *title, Window *window ) :
         Rect( x, y, w, h ) {
   font = NULL;
   hook = NULL;
+  key = 0;
 
   this->id = id;
   this->flags = flags;
-  this->key = key;
-  this->title = title;
   surface = window;
+  SetTitle( title );
 
   clicked = false;
 
@@ -133,9 +133,9 @@ GUI_Status Widget::HandleEvent( const SDL_Event &event ) {
 ////////////////////////////////////////////////////////////////////////
 
 void Widget::PrintTitle( const Color &hcol ) const {
-  if ( title ) {
+  if ( !title.empty() ) {
     unsigned short xoff, yoff;
-    unsigned short tlen = font->TextWidth(title);
+    unsigned short tlen = font->TextWidth(title.c_str());
 
     if ( flags & WIDGET_ALIGN_TOP ) {
       xoff = x + (w - tlen) / 2;
@@ -157,13 +157,13 @@ void Widget::PrintTitle( const Color &hcol ) const {
     }
 
     if ( Disabled() )
-      font->Write( title, surface, xoff, yoff, Color(CF_COLOR_GHOSTED) );
+      font->Write( title.c_str(), surface, xoff, yoff, Color(CF_COLOR_GHOSTED) );
     else {
-      font->Write( title, surface, xoff, yoff );
+      font->Write( title.c_str(), surface, xoff, yoff );
 
       // highlight keyboard shortcut
       if ( key ) {
-        char const *p = title;
+        char const *p = title.c_str();
         while ( *p != '\0' ) {
           if ( tolower( *p ) == key ) {
             font->Write( *p, surface, xoff, yoff, hcol );
@@ -177,3 +177,25 @@ void Widget::PrintTitle( const Color &hcol ) const {
   }
 }
 
+////////////////////////////////////////////////////////////////////////
+// NAME       : Widget::SetTitle
+// DESCRIPTION: Set the widget title. An underscore character in the
+//              title string designates the following character as the
+//              keyboard shortcut for this widget.
+// PARAMETERS : str - widget title
+// RETURNS    : -
+////////////////////////////////////////////////////////////////////////
+
+void Widget::SetTitle( const char *str ) {
+  title.erase();
+
+  if ( str ) {
+    int len = strlen( str );
+
+    for ( int i = 0; i < len; ++i ) {
+      if ( str[i] != '_' ) title += str[i];
+      else if ( i < len - 1 ) key = tolower( str[i+1] );
+    }
+  }
+}
+
